# Auto-generated by scripts/scaffold_rules.py
from . import registry


@registry.register("6.1.1", text="एकाचो द्वे प्रथमस्य ।")
def rule_6_1_1(ctx=None):
    """
    6.1.1: एकाचो द्वे प्रथमस्य ।
    """
    pass


@registry.register("6.1.2", text="अजादेर्द्वितीयस्य ।")
def rule_6_1_2(ctx=None):
    """
    6.1.2: अजादेर्द्वितीयस्य ।
    """
    pass


@registry.register("6.1.3", text="न न्द्राः संयोगादयः ।")
def rule_6_1_3(ctx=None):
    """
    6.1.3: न न्द्राः संयोगादयः ।
    """
    pass


@registry.register("6.1.4", text="पूर्वोऽभ्यासः ।")
def rule_6_1_4(ctx=None):
    """
    6.1.4: पूर्वोऽभ्यासः ।
    """
    pass


@registry.register("6.1.5", text="उभे अभ्यस्तम् ।")
def rule_6_1_5(ctx=None):
    """
    6.1.5: उभे अभ्यस्तम् ।
    """
    pass


@registry.register("6.1.6", text="जक्षित्यादयः षट् ।")
def rule_6_1_6(ctx=None):
    """
    6.1.6: जक्षित्यादयः षट् ।
    """
    pass


@registry.register("6.1.7", text="तुजादीनां दीर्घोऽभ्यासस्य ।")
def rule_6_1_7(ctx=None):
    """
    6.1.7: तुजादीनां दीर्घोऽभ्यासस्य ।
    """
    pass


@registry.register("6.1.8", text="लिटि धातोरनभ्यासस्य ।")
def rule_6_1_8(ctx=None):
    """
    6.1.8: लिटि धातोरनभ्यासस्य ।
    """
    pass


@registry.register("6.1.9", text="सन्यङोः ।")
def rule_6_1_9(ctx=None):
    """
    6.1.9: सन्यङोः ।
    """
    pass


@registry.register("6.1.10", text="।")
def rule_6_1_10(ctx=None):
    """
    6.1.10: ।
    """
    pass


@registry.register("6.1.11", text="चङि ।")
def rule_6_1_11(ctx=None):
    """
    6.1.11: चङि ।
    """
    pass


@registry.register("6.1.12", text="दाश्वान् साह्वान् मीद्वांश्च ।")
def rule_6_1_12(ctx=None):
    """
    6.1.12: दाश्वान् साह्वान् मीद्वांश्च ।
    """
    pass


@registry.register("6.1.13", text="ष्यङः सम्प्रसारणं पुत्रपत्योस्तत्पुरुषे ।")
def rule_6_1_13(ctx=None):
    """
    6.1.13: ष्यङः सम्प्रसारणं पुत्रपत्योस्तत्पुरुषे ।
    """
    pass


@registry.register("6.1.14", text="बन्धुनि बहुव्रीहौ ।")
def rule_6_1_14(ctx=None):
    """
    6.1.14: बन्धुनि बहुव्रीहौ ।
    """
    pass


@registry.register("6.1.15", text="वचिस्वपियजादिनां किति ।")
def rule_6_1_15(ctx=None):
    """
    6.1.15: वचिस्वपियजादिनां किति ।
    """
    pass


@registry.register("6.1.16", text="ग्रहिज्यावयिव्यधिवष्टिविचतिवृश्चतिपृच्छतिभृज्जतीनां ङिति च ।")
def rule_6_1_16(ctx=None):
    """
    6.1.16: ग्रहिज्यावयिव्यधिवष्टिविचतिवृश्चतिपृच्छतिभृज्जतीनां ङिति च ।
    """
    pass


@registry.register("6.1.17", text="लिट्यभ्यासस्योभयेषाम् ।")
def rule_6_1_17(ctx=None):
    """
    6.1.17: लिट्यभ्यासस्योभयेषाम् ।
    """
    pass


@registry.register("6.1.18", text="स्वापेश्चङि ।")
def rule_6_1_18(ctx=None):
    """
    6.1.18: स्वापेश्चङि ।
    """
    pass


@registry.register("6.1.19", text="स्वपिस्यमिव्येञां यङि ।")
def rule_6_1_19(ctx=None):
    """
    6.1.19: स्वपिस्यमिव्येञां यङि ।
    """
    pass


@registry.register("6.1.20", text="न वशः ।")
def rule_6_1_20(ctx=None):
    """
    6.1.20: न वशः ।
    """
    pass


@registry.register("6.1.21", text="चायः की ।")
def rule_6_1_21(ctx=None):
    """
    6.1.21: चायः की ।
    """
    pass


@registry.register("6.1.22", text="स्फायः स्फी निष्ठायाम् ।")
def rule_6_1_22(ctx=None):
    """
    6.1.22: स्फायः स्फी निष्ठायाम् ।
    """
    pass


@registry.register("6.1.23", text="स्त्यः प्रपूर्वस्य ।")
def rule_6_1_23(ctx=None):
    """
    6.1.23: स्त्यः प्रपूर्वस्य ।
    """
    pass


@registry.register("6.1.24", text="द्रवमूर्तिस्पर्शयोः श्यः ।")
def rule_6_1_24(ctx=None):
    """
    6.1.24: द्रवमूर्तिस्पर्शयोः श्यः ।
    """
    pass


@registry.register("6.1.25", text="प्रतेश्च ।")
def rule_6_1_25(ctx=None):
    """
    6.1.25: प्रतेश्च ।
    """
    pass


@registry.register("6.1.26", text="विभाषाऽभ्यवपूर्वस्य ।")
def rule_6_1_26(ctx=None):
    """
    6.1.26: विभाषाऽभ्यवपूर्वस्य ।
    """
    pass


@registry.register("6.1.27", text="शृतं पाके ।")
def rule_6_1_27(ctx=None):
    """
    6.1.27: शृतं पाके ।
    """
    pass


@registry.register("6.1.28", text="प्यायः पी ।")
def rule_6_1_28(ctx=None):
    """
    6.1.28: प्यायः पी ।
    """
    pass


@registry.register("6.1.29", text="लिड्यङोश्च ।")
def rule_6_1_29(ctx=None):
    """
    6.1.29: लिड्यङोश्च ।
    """
    pass


@registry.register("6.1.30", text="विभाषा ।")
def rule_6_1_30(ctx=None):
    """
    6.1.30: विभाषा ।
    """
    pass


@registry.register("6.1.31", text="णौ च संश्चङोः ।")
def rule_6_1_31(ctx=None):
    """
    6.1.31: णौ च संश्चङोः ।
    """
    pass


@registry.register("6.1.32", text="ह्वः सम्प्रसारणम् ।")
def rule_6_1_32(ctx=None):
    """
    6.1.32: ह्वः सम्प्रसारणम् ।
    """
    pass


@registry.register("6.1.33", text="अभ्यस्तस्य च ।")
def rule_6_1_33(ctx=None):
    """
    6.1.33: अभ्यस्तस्य च ।
    """
    pass


@registry.register("6.1.34", text="बहुलं छन्दसि ।")
def rule_6_1_34(ctx=None):
    """
    6.1.34: बहुलं छन्दसि ।
    """
    pass


@registry.register("6.1.35", text="चायः की ।")
def rule_6_1_35(ctx=None):
    """
    6.1.35: चायः की ।
    """
    pass


@registry.register("6.1.36", text="अपस्पृधेथामानृचुरानृहुश्चिच्युषेतित्याजश्राताःश्रितमाशीराशीर्त्तः ।")
def rule_6_1_36(ctx=None):
    """
    6.1.36: अपस्पृधेथामानृचुरानृहुश्चिच्युषेतित्याजश्राताःश्रितमाशीराशीर्त्तः ।
    """
    pass


@registry.register("6.1.37", text="न सम्प्रसारणे सम्प्रसारणम् ।")
def rule_6_1_37(ctx=None):
    """
    6.1.37: न सम्प्रसारणे सम्प्रसारणम् ।
    """
    pass


@registry.register("6.1.38", text="लिटि वयो यः ।")
def rule_6_1_38(ctx=None):
    """
    6.1.38: लिटि वयो यः ।
    """
    pass


@registry.register("6.1.39", text="वश्चास्यान्यतरस्याम् किति ।")
def rule_6_1_39(ctx=None):
    """
    6.1.39: वश्चास्यान्यतरस्याम् किति ।
    """
    pass


@registry.register("6.1.40", text="वेञः ।")
def rule_6_1_40(ctx=None):
    """
    6.1.40: वेञः ।
    """
    pass


@registry.register("6.1.41", text="ल्यपि च ।")
def rule_6_1_41(ctx=None):
    """
    6.1.41: ल्यपि च ।
    """
    pass


@registry.register("6.1.42", text="ज्यश्च ।")
def rule_6_1_42(ctx=None):
    """
    6.1.42: ज्यश्च ।
    """
    pass


@registry.register("6.1.43", text="व्यश्च ।")
def rule_6_1_43(ctx=None):
    """
    6.1.43: व्यश्च ।
    """
    pass


@registry.register("6.1.44", text="विभाषा परेः ।")
def rule_6_1_44(ctx=None):
    """
    6.1.44: विभाषा परेः ।
    """
    pass


@registry.register("6.1.45", text="आदेच उपदेशेऽशिति ।")
def rule_6_1_45(ctx=None):
    """
    6.1.45: आदेच उपदेशेऽशिति ।
    """
    pass


@registry.register("6.1.46", text="न व्यो लिटि ।")
def rule_6_1_46(ctx=None):
    """
    6.1.46: न व्यो लिटि ।
    """
    pass


@registry.register("6.1.47", text="स्फुरतिस्फुलत्योर्घञि ।")
def rule_6_1_47(ctx=None):
    """
    6.1.47: स्फुरतिस्फुलत्योर्घञि ।
    """
    pass


@registry.register("6.1.48", text="क्रीड्ङ्गीनां णौ ।")
def rule_6_1_48(ctx=None):
    """
    6.1.48: क्रीड्ङ्गीनां णौ ।
    """
    pass


@registry.register("6.1.49", text="सिध्यतेरपारलौकिके ।")
def rule_6_1_49(ctx=None):
    """
    6.1.49: सिध्यतेरपारलौकिके ।
    """
    pass


@registry.register("6.1.50", text="मीनातिमिनोतिदीङां ल्यपि च ।")
def rule_6_1_50(ctx=None):
    """
    6.1.50: मीनातिमिनोतिदीङां ल्यपि च ।
    """
    pass


@registry.register("6.1.51", text="विभाषा लीयतेः ।")
def rule_6_1_51(ctx=None):
    """
    6.1.51: विभाषा लीयतेः ।
    """
    pass


@registry.register("6.1.52", text="खिदेश्छन्दसि ।")
def rule_6_1_52(ctx=None):
    """
    6.1.52: खिदेश्छन्दसि ।
    """
    pass


@registry.register("6.1.53", text="अपगुरो णमुलि ।")
def rule_6_1_53(ctx=None):
    """
    6.1.53: अपगुरो णमुलि ।
    """
    pass


@registry.register("6.1.54", text="चिस्फुरोर्णो ।")
def rule_6_1_54(ctx=None):
    """
    6.1.54: चिस्फुरोर्णो ।
    """
    pass


@registry.register("6.1.55", text="प्रजने वीयतेः ।")
def rule_6_1_55(ctx=None):
    """
    6.1.55: प्रजने वीयतेः ।
    """
    pass


@registry.register("6.1.56", text="बिभेतेर्हेतुभये ।")
def rule_6_1_56(ctx=None):
    """
    6.1.56: बिभेतेर्हेतुभये ।
    """
    pass


@registry.register("6.1.57", text="नित्यं स्मयतेः ।")
def rule_6_1_57(ctx=None):
    """
    6.1.57: नित्यं स्मयतेः ।
    """
    pass


@registry.register("6.1.58", text="सृजिदृशोर्झल्यमकिति ।")
def rule_6_1_58(ctx=None):
    """
    6.1.58: सृजिदृशोर्झल्यमकिति ।
    """
    pass


@registry.register("6.1.59", text="अनुदात्तस्य चर्दुपधस्यान्यतरस्याम् ।")
def rule_6_1_59(ctx=None):
    """
    6.1.59: अनुदात्तस्य चर्दुपधस्यान्यतरस्याम् ।
    """
    pass


@registry.register("6.1.60", text="शीर्षश्छन्दसि ।")
def rule_6_1_60(ctx=None):
    """
    6.1.60: शीर्षश्छन्दसि ।
    """
    pass


@registry.register("6.1.61", text="ये च तद्धिते ।")
def rule_6_1_61(ctx=None):
    """
    6.1.61: ये च तद्धिते ।
    """
    pass


@registry.register("6.1.62", text="अचि शीर्षः ।")
def rule_6_1_62(ctx=None):
    """
    6.1.62: अचि शीर्षः ।
    """
    pass


@registry.register("6.1.63", text="पद्दनोमाशृन्निशसन्यूषन्दोषन्यकञ्छकनुदन्नासञ्छस्प्रभृतिषु ।")
def rule_6_1_63(ctx=None):
    """
    6.1.63: पद्दनोमाशृन्निशसन्यूषन्दोषन्यकञ्छकनुदन्नासञ्छस्प्रभृतिषु ।
    """
    pass


@registry.register("6.1.64", text="धात्वादेः षः सः ।")
def rule_6_1_64(ctx=None):
    """
    6.1.64: धात्वादेः षः सः ।
    """
    pass


@registry.register("6.1.65", text="णो नः ।")
def rule_6_1_65(ctx=None):
    """
    6.1.65: णो नः ।
    """
    pass


@registry.register("6.1.66", text="लोपो व्योर्वलि ।")
def rule_6_1_66(ctx=None):
    """
    6.1.66: लोपो व्योर्वलि ।
    """
    pass


@registry.register("6.1.67", text="वेरपृक्तस्य ।")
def rule_6_1_67(ctx=None):
    """
    6.1.67: वेरपृक्तस्य ।
    """
    pass


@registry.register("6.1.68", text="हल्याब्भ्यो दीर्घात् सुतिस्यपृक्तं हल् ।")
def rule_6_1_68(ctx=None):
    """
    6.1.68: हल्याब्भ्यो दीर्घात् सुतिस्यपृक्तं हल् ।
    """
    pass


@registry.register("6.1.69", text="एङ्कस्वात् सम्बुद्धेः ।")
def rule_6_1_69(ctx=None):
    """
    6.1.69: एङ्कस्वात् सम्बुद्धेः ।
    """
    pass


@registry.register("6.1.70", text="शेश्छन्दसि बहुलम् ।")
def rule_6_1_70(ctx=None):
    """
    6.1.70: शेश्छन्दसि बहुलम् ।
    """
    pass


@registry.register("6.1.71", text="ह्रस्वस्य पिति कृति तुक् ।")
def rule_6_1_71(ctx=None):
    """
    6.1.71: ह्रस्वस्य पिति कृति तुक् ।
    """
    pass


@registry.register("6.1.72", text="संहितायाम् ।")
def rule_6_1_72(ctx=None):
    """
    6.1.72: संहितायाम् ।
    """
    pass


@registry.register("6.1.73", text="छे च ।")
def rule_6_1_73(ctx=None):
    """
    6.1.73: छे च ।
    """
    pass


@registry.register("6.1.74", text="आङ्गाङोश्च ।")
def rule_6_1_74(ctx=None):
    """
    6.1.74: आङ्गाङोश्च ।
    """
    pass


@registry.register("6.1.75", text="दीर्घात् ।")
def rule_6_1_75(ctx=None):
    """
    6.1.75: दीर्घात् ।
    """
    pass


@registry.register("6.1.76", text="पदान्ताद्वा ।")
def rule_6_1_76(ctx=None):
    """
    6.1.76: पदान्ताद्वा ।
    """
    pass


@registry.register("6.1.77", text="इको यणचि ।")
def rule_6_1_77(ctx=None):
    """
    6.1.77: इको यणचि ।
    """
    pass


@registry.register("6.1.78", text="एचोऽयवायावः ।")
def rule_6_1_78(ctx=None):
    """
    6.1.78: एचोऽयवायावः ।
    """
    pass


@registry.register("6.1.79", text="वान्तो यि प्रत्यये ।")
def rule_6_1_79(ctx=None):
    """
    6.1.79: वान्तो यि प्रत्यये ।
    """
    pass


@registry.register("6.1.80", text="धातोस्तन्निमित्तस्यैव ।")
def rule_6_1_80(ctx=None):
    """
    6.1.80: धातोस्तन्निमित्तस्यैव ।
    """
    pass


@registry.register("6.1.81", text="क्षय्यजय्यौ शक्यार्थे ।")
def rule_6_1_81(ctx=None):
    """
    6.1.81: क्षय्यजय्यौ शक्यार्थे ।
    """
    pass


@registry.register("6.1.82", text="क्रय्यस्तदर्थे ।")
def rule_6_1_82(ctx=None):
    """
    6.1.82: क्रय्यस्तदर्थे ।
    """
    pass


@registry.register("6.1.83", text="भय्यप्रवय्ये च च्छन्दसि ।")
def rule_6_1_83(ctx=None):
    """
    6.1.83: भय्यप्रवय्ये च च्छन्दसि ।
    """
    pass


@registry.register("6.1.84", text="एकः पूर्वपरयोः ।")
def rule_6_1_84(ctx=None):
    """
    6.1.84: एकः पूर्वपरयोः ।
    """
    pass


@registry.register("6.1.85", text="अन्तादिवच्च ।")
def rule_6_1_85(ctx=None):
    """
    6.1.85: अन्तादिवच्च ।
    """
    pass


@registry.register("6.1.86", text="षत्वतुकोरसिद्धः ।")
def rule_6_1_86(ctx=None):
    """
    6.1.86: षत्वतुकोरसिद्धः ।
    """
    pass


@registry.register("6.1.87", text="आगुणः ।")
def rule_6_1_87(ctx=None):
    """
    6.1.87: आगुणः ।
    """
    pass


@registry.register("6.1.88", text="वृद्धिरेचि ।")
def rule_6_1_88(ctx=None):
    """
    6.1.88: वृद्धिरेचि ।
    """
    pass


@registry.register("6.1.89", text="एत्येधत्यूट्छु ।")
def rule_6_1_89(ctx=None):
    """
    6.1.89: एत्येधत्यूट्छु ।
    """
    pass


@registry.register("6.1.90", text="आटश्च ।")
def rule_6_1_90(ctx=None):
    """
    6.1.90: आटश्च ।
    """
    pass


@registry.register("6.1.91", text="उपसर्गादृति धातौ ।")
def rule_6_1_91(ctx=None):
    """
    6.1.91: उपसर्गादृति धातौ ।
    """
    pass


@registry.register("6.1.92", text="वा सुप्यापिशलेः ।")
def rule_6_1_92(ctx=None):
    """
    6.1.92: वा सुप्यापिशलेः ।
    """
    pass


@registry.register("6.1.93", text="ओतोऽम्शसोः ।")
def rule_6_1_93(ctx=None):
    """
    6.1.93: ओतोऽम्शसोः ।
    """
    pass


@registry.register("6.1.94", text="एङि पररूपम् ।")
def rule_6_1_94(ctx=None):
    """
    6.1.94: एङि पररूपम् ।
    """
    pass


@registry.register("6.1.95", text="ओमाङोश्च ।")
def rule_6_1_95(ctx=None):
    """
    6.1.95: ओमाङोश्च ।
    """
    pass


@registry.register("6.1.96", text="उस्यपदान्तात् ।")
def rule_6_1_96(ctx=None):
    """
    6.1.96: उस्यपदान्तात् ।
    """
    pass


@registry.register("6.1.97", text="अतो गुणे ।")
def rule_6_1_97(ctx=None):
    """
    6.1.97: अतो गुणे ।
    """
    pass


@registry.register("6.1.98", text="अव्यक्तानुकरणस्यात इतौ ।")
def rule_6_1_98(ctx=None):
    """
    6.1.98: अव्यक्तानुकरणस्यात इतौ ।
    """
    pass


@registry.register("6.1.99", text="नाम्रेडितस्यान्त्यस्य तु वा ।")
def rule_6_1_99(ctx=None):
    """
    6.1.99: नाम्रेडितस्यान्त्यस्य तु वा ।
    """
    pass


@registry.register("6.1.100", text="नित्यमाग्रेडिते डाचि ।")
def rule_6_1_100(ctx=None):
    """
    6.1.100: नित्यमाग्रेडिते डाचि ।
    """
    pass


@registry.register("6.1.101", text="अकः सवर्णे दीर्घः ।")
def rule_6_1_101(ctx=None):
    """
    6.1.101: अकः सवर्णे दीर्घः ।
    """
    pass


@registry.register("6.1.102", text="प्रथमयोः पूर्वसवर्णः ।")
def rule_6_1_102(ctx=None):
    """
    6.1.102: प्रथमयोः पूर्वसवर्णः ।
    """
    pass


@registry.register("6.1.103", text="तस्माच्छसो नः पुंसि ।")
def rule_6_1_103(ctx=None):
    """
    6.1.103: तस्माच्छसो नः पुंसि ।
    """
    pass


@registry.register("6.1.104", text="नादिचि ।")
def rule_6_1_104(ctx=None):
    """
    6.1.104: नादिचि ।
    """
    pass


@registry.register("6.1.105", text="दीर्घाज्ञ्जसि च ।")
def rule_6_1_105(ctx=None):
    """
    6.1.105: दीर्घाज्ञ्जसि च ।
    """
    pass


@registry.register("6.1.106", text="वा छन्दसि ।")
def rule_6_1_106(ctx=None):
    """
    6.1.106: वा छन्दसि ।
    """
    pass


@registry.register("6.1.107", text="अमि पूर्वः ।")
def rule_6_1_107(ctx=None):
    """
    6.1.107: अमि पूर्वः ।
    """
    pass


@registry.register("6.1.108", text="सम्प्रसारणाच्च ।")
def rule_6_1_108(ctx=None):
    """
    6.1.108: सम्प्रसारणाच्च ।
    """
    pass


@registry.register("6.1.109", text="एङः पदान्तादति ।")
def rule_6_1_109(ctx=None):
    """
    6.1.109: एङः पदान्तादति ।
    """
    pass


@registry.register("6.1.110", text="ङसिङसोश्च ।")
def rule_6_1_110(ctx=None):
    """
    6.1.110: ङसिङसोश्च ।
    """
    pass


@registry.register("6.1.111", text="ऋत उत् ।")
def rule_6_1_111(ctx=None):
    """
    6.1.111: ऋत उत् ।
    """
    pass


@registry.register("6.1.112", text="ख्यत्यात् परस्य ।")
def rule_6_1_112(ctx=None):
    """
    6.1.112: ख्यत्यात् परस्य ।
    """
    pass


@registry.register("6.1.113", text="अतो रोरप्लुतादप्लुते ।")
def rule_6_1_113(ctx=None):
    """
    6.1.113: अतो रोरप्लुतादप्लुते ।
    """
    pass


@registry.register("6.1.114", text="हशि च ।")
def rule_6_1_114(ctx=None):
    """
    6.1.114: हशि च ।
    """
    pass


@registry.register("6.1.115", text="प्रकृत्याऽन्तःपादमव्यपरे ।")
def rule_6_1_115(ctx=None):
    """
    6.1.115: प्रकृत्याऽन्तःपादमव्यपरे ।
    """
    pass


@registry.register("6.1.116", text="अव्यादवद्यादवक्रमुरव्रतायमवन्त्ववस्युषु च ।")
def rule_6_1_116(ctx=None):
    """
    6.1.116: अव्यादवद्यादवक्रमुरव्रतायमवन्त्ववस्युषु च ।
    """
    pass


@registry.register("6.1.117", text="यजुष्युरः ।")
def rule_6_1_117(ctx=None):
    """
    6.1.117: यजुष्युरः ।
    """
    pass


@registry.register("6.1.118", text="आपोजुषाणोवृष्णोवर्षिष्ठेऽम्बे ऽम्बाले ऽम्बिकेपूर्वे ।")
def rule_6_1_118(ctx=None):
    """
    6.1.118: आपोजुषाणोवृष्णोवर्षिष्ठेऽम्बे ऽम्बाले ऽम्बिकेपूर्वे ।
    """
    pass


@registry.register("6.1.119", text="अङ्ग इत्यादौ च ।")
def rule_6_1_119(ctx=None):
    """
    6.1.119: अङ्ग इत्यादौ च ।
    """
    pass


@registry.register("6.1.120", text="अनुदात्ते च कुधपरे ।")
def rule_6_1_120(ctx=None):
    """
    6.1.120: अनुदात्ते च कुधपरे ।
    """
    pass


@registry.register("6.1.121", text="अवपथासि च ।")
def rule_6_1_121(ctx=None):
    """
    6.1.121: अवपथासि च ।
    """
    pass


@registry.register("6.1.122", text="सर्वत्र विभाषा गोः ।")
def rule_6_1_122(ctx=None):
    """
    6.1.122: सर्वत्र विभाषा गोः ।
    """
    pass


@registry.register("6.1.123", text="अवङ् स्फोटायनस्य ।")
def rule_6_1_123(ctx=None):
    """
    6.1.123: अवङ् स्फोटायनस्य ।
    """
    pass


@registry.register("6.1.124", text="इन्द्रे च (नित्यम्) ।")
def rule_6_1_124(ctx=None):
    """
    6.1.124: इन्द्रे च (नित्यम्) ।
    """
    pass


@registry.register("6.1.125", text="प्लुतप्रगृह्या अचि नित्यम् ।")
def rule_6_1_125(ctx=None):
    """
    6.1.125: प्लुतप्रगृह्या अचि नित्यम् ।
    """
    pass


@registry.register("6.1.126", text="आङोऽनुनासिकश्छन्दसि ।")
def rule_6_1_126(ctx=None):
    """
    6.1.126: आङोऽनुनासिकश्छन्दसि ।
    """
    pass


@registry.register("6.1.127", text="इकोऽसवर्णे शाकल्यस्य ह्रस्वश्च ।")
def rule_6_1_127(ctx=None):
    """
    6.1.127: इकोऽसवर्णे शाकल्यस्य ह्रस्वश्च ।
    """
    pass


@registry.register("6.1.128", text="ऋत्यकः ।")
def rule_6_1_128(ctx=None):
    """
    6.1.128: ऋत्यकः ।
    """
    pass


@registry.register("6.1.129", text="अप्नुतवदुपस्थिते ।")
def rule_6_1_129(ctx=None):
    """
    6.1.129: अप्नुतवदुपस्थिते ।
    """
    pass


@registry.register("6.1.130", text="ई३ चाक्रवर्मणस्य ।")
def rule_6_1_130(ctx=None):
    """
    6.1.130: ई३ चाक्रवर्मणस्य ।
    """
    pass


@registry.register("6.1.131", text="दिव उत् ।")
def rule_6_1_131(ctx=None):
    """
    6.1.131: दिव उत् ।
    """
    pass


@registry.register("6.1.132", text="एतत्तदोः सुलोपोऽकोरनञ्समासे हलि ।")
def rule_6_1_132(ctx=None):
    """
    6.1.132: एतत्तदोः सुलोपोऽकोरनञ्समासे हलि ।
    """
    pass


@registry.register("6.1.133", text="स्यश्छन्दसि बहुलम् ।")
def rule_6_1_133(ctx=None):
    """
    6.1.133: स्यश्छन्दसि बहुलम् ।
    """
    pass


@registry.register("6.1.134", text="सोऽचि लोपे चेत् पादपूरणम् ।")
def rule_6_1_134(ctx=None):
    """
    6.1.134: सोऽचि लोपे चेत् पादपूरणम् ।
    """
    pass


@registry.register("6.1.135", text="सुट् कात् पूर्वः ।")
def rule_6_1_135(ctx=None):
    """
    6.1.135: सुट् कात् पूर्वः ।
    """
    pass


@registry.register("6.1.136", text="अडभ्यासव्यवायेऽपि ।")
def rule_6_1_136(ctx=None):
    """
    6.1.136: अडभ्यासव्यवायेऽपि ।
    """
    pass


@registry.register("6.1.137", text="सम्पर्युपेभ्यः करोतौ भूषणे ।")
def rule_6_1_137(ctx=None):
    """
    6.1.137: सम्पर्युपेभ्यः करोतौ भूषणे ।
    """
    pass


@registry.register("6.1.138", text="समवाये च ।")
def rule_6_1_138(ctx=None):
    """
    6.1.138: समवाये च ।
    """
    pass


@registry.register("6.1.139", text="उपात् प्रतियत्नवैकृतवाक्याध्याहारेषु ।")
def rule_6_1_139(ctx=None):
    """
    6.1.139: उपात् प्रतियत्नवैकृतवाक्याध्याहारेषु ।
    """
    pass


@registry.register("6.1.140", text="किरतौ लवने ।")
def rule_6_1_140(ctx=None):
    """
    6.1.140: किरतौ लवने ।
    """
    pass


@registry.register("6.1.141", text="हिंसायां प्रतेश्च ।")
def rule_6_1_141(ctx=None):
    """
    6.1.141: हिंसायां प्रतेश्च ।
    """
    pass


@registry.register("6.1.142", text="अपाच्चतुष्पाच्छकुनिष्वालेखने ।")
def rule_6_1_142(ctx=None):
    """
    6.1.142: अपाच्चतुष्पाच्छकुनिष्वालेखने ।
    """
    pass


@registry.register("6.1.143", text="कुस्तुम्बुरूणि जातिः ।")
def rule_6_1_143(ctx=None):
    """
    6.1.143: कुस्तुम्बुरूणि जातिः ।
    """
    pass


@registry.register("6.1.144", text="अपरस्पराः क्रियासातत्ये ।")
def rule_6_1_144(ctx=None):
    """
    6.1.144: अपरस्पराः क्रियासातत्ये ।
    """
    pass


@registry.register("6.1.145", text="गोष्पदं सेवितासेवितप्रमाणेषु ।")
def rule_6_1_145(ctx=None):
    """
    6.1.145: गोष्पदं सेवितासेवितप्रमाणेषु ।
    """
    pass


@registry.register("6.1.146", text="आस्पदं प्रतिष्ठायाम् ।")
def rule_6_1_146(ctx=None):
    """
    6.1.146: आस्पदं प्रतिष्ठायाम् ।
    """
    pass


@registry.register("6.1.147", text="आश्चर्यमनित्ये ।")
def rule_6_1_147(ctx=None):
    """
    6.1.147: आश्चर्यमनित्ये ।
    """
    pass


@registry.register("6.1.148", text="वर्चस्केऽवस्करः ।")
def rule_6_1_148(ctx=None):
    """
    6.1.148: वर्चस्केऽवस्करः ।
    """
    pass


@registry.register("6.1.149", text="अपस्करो रथाङ्गम् ।")
def rule_6_1_149(ctx=None):
    """
    6.1.149: अपस्करो रथाङ्गम् ।
    """
    pass


@registry.register("6.1.150", text="विष्किरः शकुनिर्विकरो वा ।")
def rule_6_1_150(ctx=None):
    """
    6.1.150: विष्किरः शकुनिर्विकरो वा ।
    """
    pass


@registry.register("6.1.151", text="ह्रस्वाच्चन्द्रोत्तरपदे मन्त्रे ।")
def rule_6_1_151(ctx=None):
    """
    6.1.151: ह्रस्वाच्चन्द्रोत्तरपदे मन्त्रे ।
    """
    pass


@registry.register("6.1.152", text="प्रतिष्कशश्च कशेः ।")
def rule_6_1_152(ctx=None):
    """
    6.1.152: प्रतिष्कशश्च कशेः ।
    """
    pass


@registry.register("6.1.153", text="प्रस्कण्वहरिश्चन्द्रावृषी ।")
def rule_6_1_153(ctx=None):
    """
    6.1.153: प्रस्कण्वहरिश्चन्द्रावृषी ।
    """
    pass


@registry.register("6.1.154", text="मस्करमस्करिणौ वेणुपरिव्राजकयोः ।")
def rule_6_1_154(ctx=None):
    """
    6.1.154: मस्करमस्करिणौ वेणुपरिव्राजकयोः ।
    """
    pass


@registry.register("6.1.155", text="कास्तीराजस्तुन्दे नगरे ।")
def rule_6_1_155(ctx=None):
    """
    6.1.155: कास्तीराजस्तुन्दे नगरे ।
    """
    pass


@registry.register("6.1.156", text="कारस्करो वृक्षः ।")
def rule_6_1_156(ctx=None):
    """
    6.1.156: कारस्करो वृक्षः ।
    """
    pass


@registry.register("6.1.157", text="पारस्करप्रभृतीनि च संज्ञायाम् ।")
def rule_6_1_157(ctx=None):
    """
    6.1.157: पारस्करप्रभृतीनि च संज्ञायाम् ।
    """
    pass


@registry.register("6.1.158", text="अनुदात्तं पदमेकवर्जम् ।")
def rule_6_1_158(ctx=None):
    """
    6.1.158: अनुदात्तं पदमेकवर्जम् ।
    """
    pass


@registry.register("6.1.159", text="कर्षात्वतो घञोऽन्त उदात्तः ।")
def rule_6_1_159(ctx=None):
    """
    6.1.159: कर्षात्वतो घञोऽन्त उदात्तः ।
    """
    pass


@registry.register("6.1.160", text="उञ्छादीनां च ।")
def rule_6_1_160(ctx=None):
    """
    6.1.160: उञ्छादीनां च ।
    """
    pass


@registry.register("6.1.161", text="अनुदात्तस्य च यत्रोदात्तलोपः ।")
def rule_6_1_161(ctx=None):
    """
    6.1.161: अनुदात्तस्य च यत्रोदात्तलोपः ।
    """
    pass


@registry.register("6.1.162", text="धातोः ।")
def rule_6_1_162(ctx=None):
    """
    6.1.162: धातोः ।
    """
    pass


@registry.register("6.1.163", text="चितः ।")
def rule_6_1_163(ctx=None):
    """
    6.1.163: चितः ।
    """
    pass


@registry.register("6.1.164", text="तद्धितस्य ।")
def rule_6_1_164(ctx=None):
    """
    6.1.164: तद्धितस्य ।
    """
    pass


@registry.register("6.1.165", text="कितः ।")
def rule_6_1_165(ctx=None):
    """
    6.1.165: कितः ।
    """
    pass


@registry.register("6.1.166", text="तिसृभ्यो जसः ।")
def rule_6_1_166(ctx=None):
    """
    6.1.166: तिसृभ्यो जसः ।
    """
    pass


@registry.register("6.1.167", text="चतुरः शसि ।")
def rule_6_1_167(ctx=None):
    """
    6.1.167: चतुरः शसि ।
    """
    pass


@registry.register("6.1.168", text="सावेकाचस्तृतीयाऽऽदिविभक्तिः ।")
def rule_6_1_168(ctx=None):
    """
    6.1.168: सावेकाचस्तृतीयाऽऽदिविभक्तिः ।
    """
    pass


@registry.register("6.1.169", text="अन्तोदत्तादुत्तरपदादन्यतरस्यामनित्यसमासे ।")
def rule_6_1_169(ctx=None):
    """
    6.1.169: अन्तोदत्तादुत्तरपदादन्यतरस्यामनित्यसमासे ।
    """
    pass


@registry.register("6.1.170", text="अञ्चेश्छन्दस्यसर्वनामस्थानम् ।")
def rule_6_1_170(ctx=None):
    """
    6.1.170: अञ्चेश्छन्दस्यसर्वनामस्थानम् ।
    """
    pass


@registry.register("6.1.171", text="ऊडिदम्पदाद्यप्पुत्रैद्युभ्यः ।")
def rule_6_1_171(ctx=None):
    """
    6.1.171: ऊडिदम्पदाद्यप्पुत्रैद्युभ्यः ।
    """
    pass


@registry.register("6.1.172", text="अष्टनो दीर्घात् ।")
def rule_6_1_172(ctx=None):
    """
    6.1.172: अष्टनो दीर्घात् ।
    """
    pass


@registry.register("6.1.173", text="शतुरनुमो नद्यजादी ।")
def rule_6_1_173(ctx=None):
    """
    6.1.173: शतुरनुमो नद्यजादी ।
    """
    pass


@registry.register("6.1.174", text="उदात्तयणो हल्पूर्वात् ।")
def rule_6_1_174(ctx=None):
    """
    6.1.174: उदात्तयणो हल्पूर्वात् ।
    """
    pass


@registry.register("6.1.175", text="नोङ्घात्वोः ।")
def rule_6_1_175(ctx=None):
    """
    6.1.175: नोङ्घात्वोः ।
    """
    pass


@registry.register("6.1.176", text="ह्रस्वनुड्यां मतुप् ।")
def rule_6_1_176(ctx=None):
    """
    6.1.176: ह्रस्वनुड्यां मतुप् ।
    """
    pass


@registry.register("6.1.177", text="नामन्यतरस्याम् ।")
def rule_6_1_177(ctx=None):
    """
    6.1.177: नामन्यतरस्याम् ।
    """
    pass


@registry.register("6.1.178", text="ड्याश्छन्दसि बहुलम् ।")
def rule_6_1_178(ctx=None):
    """
    6.1.178: ड्याश्छन्दसि बहुलम् ।
    """
    pass


@registry.register("6.1.179", text="षङ्गिचतुर्थ्यो हलादिः ।")
def rule_6_1_179(ctx=None):
    """
    6.1.179: षङ्गिचतुर्थ्यो हलादिः ।
    """
    pass


@registry.register("6.1.180", text="झल्युपोत्तमम् ।")
def rule_6_1_180(ctx=None):
    """
    6.1.180: झल्युपोत्तमम् ।
    """
    pass


@registry.register("6.1.181", text="विभाषा भाषायाम् ।")
def rule_6_1_181(ctx=None):
    """
    6.1.181: विभाषा भाषायाम् ।
    """
    pass


@registry.register("6.1.182", text="न गोश्वन्त्साववर्णराडङ्कुङ्कुच्यः ।")
def rule_6_1_182(ctx=None):
    """
    6.1.182: न गोश्वन्त्साववर्णराडङ्कुङ्कुच्यः ।
    """
    pass


@registry.register("6.1.183", text="दिवो झल् ।")
def rule_6_1_183(ctx=None):
    """
    6.1.183: दिवो झल् ।
    """
    pass


@registry.register("6.1.184", text="नृ चान्यतरस्याम् ।")
def rule_6_1_184(ctx=None):
    """
    6.1.184: नृ चान्यतरस्याम् ।
    """
    pass


@registry.register("6.1.185", text="तित्स्वरितम् ।")
def rule_6_1_185(ctx=None):
    """
    6.1.185: तित्स्वरितम् ।
    """
    pass


@registry.register("6.1.186", text="तास्यनुदात्तेन्ङिददुपदेशाल्लसार्वधातुकम्- अनुदात्तमहन्विङोः ।")
def rule_6_1_186(ctx=None):
    """
    6.1.186: तास्यनुदात्तेन्ङिददुपदेशाल्लसार्वधातुकम्- अनुदात्तमहन्विङोः ।
    """
    pass


@registry.register("6.1.187", text="आदिः सिचोऽन्यतरस्याम् ।")
def rule_6_1_187(ctx=None):
    """
    6.1.187: आदिः सिचोऽन्यतरस्याम् ।
    """
    pass


@registry.register("6.1.188", text="स्वपादिहिंसामच्यनिटि ।")
def rule_6_1_188(ctx=None):
    """
    6.1.188: स्वपादिहिंसामच्यनिटि ।
    """
    pass


@registry.register("6.1.189", text="अभ्यस्तानामादिः ।")
def rule_6_1_189(ctx=None):
    """
    6.1.189: अभ्यस्तानामादिः ।
    """
    pass


@registry.register("6.1.190", text="अनुदात्ते च ।")
def rule_6_1_190(ctx=None):
    """
    6.1.190: अनुदात्ते च ।
    """
    pass


@registry.register("6.1.191", text="सर्वस्य सुपि ।")
def rule_6_1_191(ctx=None):
    """
    6.1.191: सर्वस्य सुपि ।
    """
    pass


@registry.register("6.1.192", text="भीहीभृहुमदजनधनदरिद्राजागरां प्रत्ययात् पूर्वम् पिति ।")
def rule_6_1_192(ctx=None):
    """
    6.1.192: भीहीभृहुमदजनधनदरिद्राजागरां प्रत्ययात् पूर्वम् पिति ।
    """
    pass


@registry.register("6.1.193", text="लिति ।")
def rule_6_1_193(ctx=None):
    """
    6.1.193: लिति ।
    """
    pass


@registry.register("6.1.194", text="आदिर्णमुल्यन्यतरस्याम् ।")
def rule_6_1_194(ctx=None):
    """
    6.1.194: आदिर्णमुल्यन्यतरस्याम् ।
    """
    pass


@registry.register("6.1.195", text="अचः कर्तृयकि ।")
def rule_6_1_195(ctx=None):
    """
    6.1.195: अचः कर्तृयकि ।
    """
    pass


@registry.register("6.1.196", text="थलि च सेटीडन्तो वा ।")
def rule_6_1_196(ctx=None):
    """
    6.1.196: थलि च सेटीडन्तो वा ।
    """
    pass


@registry.register("6.1.197", text="णित्यादिर्नित्यम् ।")
def rule_6_1_197(ctx=None):
    """
    6.1.197: णित्यादिर्नित्यम् ।
    """
    pass


@registry.register("6.1.198", text="आमन्त्रितस्य च ।")
def rule_6_1_198(ctx=None):
    """
    6.1.198: आमन्त्रितस्य च ।
    """
    pass


@registry.register("6.1.199", text="पथिमथोः सर्वनामस्थाने ।")
def rule_6_1_199(ctx=None):
    """
    6.1.199: पथिमथोः सर्वनामस्थाने ।
    """
    pass


@registry.register("6.1.200", text="अन्तश्च तवै युगपत् ।")
def rule_6_1_200(ctx=None):
    """
    6.1.200: अन्तश्च तवै युगपत् ।
    """
    pass


@registry.register("6.1.201", text="क्षयो निवासे ।")
def rule_6_1_201(ctx=None):
    """
    6.1.201: क्षयो निवासे ।
    """
    pass


@registry.register("6.1.202", text="जयः करणम् ।")
def rule_6_1_202(ctx=None):
    """
    6.1.202: जयः करणम् ।
    """
    pass


@registry.register("6.1.203", text="वृषादीनां च ।")
def rule_6_1_203(ctx=None):
    """
    6.1.203: वृषादीनां च ।
    """
    pass


@registry.register("6.1.204", text="संज्ञायामुपमानम् ।")
def rule_6_1_204(ctx=None):
    """
    6.1.204: संज्ञायामुपमानम् ।
    """
    pass


@registry.register("6.1.205", text="निष्ठा च व्यजनात् ।")
def rule_6_1_205(ctx=None):
    """
    6.1.205: निष्ठा च व्यजनात् ।
    """
    pass


@registry.register("6.1.206", text="शुष्कधृष्टौ ।")
def rule_6_1_206(ctx=None):
    """
    6.1.206: शुष्कधृष्टौ ।
    """
    pass


@registry.register("6.1.207", text="आशितः कर्ता ।")
def rule_6_1_207(ctx=None):
    """
    6.1.207: आशितः कर्ता ।
    """
    pass


@registry.register("6.1.208", text="रिक्त विभाषा ।")
def rule_6_1_208(ctx=None):
    """
    6.1.208: रिक्त विभाषा ।
    """
    pass


@registry.register("6.1.209", text="जुष्टार्पिते च छन्दसि ।")
def rule_6_1_209(ctx=None):
    """
    6.1.209: जुष्टार्पिते च छन्दसि ।
    """
    pass


@registry.register("6.1.210", text="नित्यं मन्त्रे ।")
def rule_6_1_210(ctx=None):
    """
    6.1.210: नित्यं मन्त्रे ।
    """
    pass


@registry.register("6.1.211", text="युष्मदस्मदोर्डसि ।")
def rule_6_1_211(ctx=None):
    """
    6.1.211: युष्मदस्मदोर्डसि ।
    """
    pass


@registry.register("6.1.212", text="ङयि च ।")
def rule_6_1_212(ctx=None):
    """
    6.1.212: ङयि च ।
    """
    pass


@registry.register("6.1.213", text="यतोऽनावः ।")
def rule_6_1_213(ctx=None):
    """
    6.1.213: यतोऽनावः ।
    """
    pass


@registry.register("6.1.214", text="ईडवन्दवृशंसदुहां ण्यतः ।")
def rule_6_1_214(ctx=None):
    """
    6.1.214: ईडवन्दवृशंसदुहां ण्यतः ।
    """
    pass


@registry.register("6.1.215", text="विभाषा वेण्विन्धानयोः ।")
def rule_6_1_215(ctx=None):
    """
    6.1.215: विभाषा वेण्विन्धानयोः ।
    """
    pass


@registry.register("6.1.216", text="त्यागरागहासकुहश्वठक्रथानाम् ।")
def rule_6_1_216(ctx=None):
    """
    6.1.216: त्यागरागहासकुहश्वठक्रथानाम् ।
    """
    pass


@registry.register("6.1.217", text="उपोत्तमं रिति ।")
def rule_6_1_217(ctx=None):
    """
    6.1.217: उपोत्तमं रिति ।
    """
    pass


@registry.register("6.1.218", text="चड्यन्यतरस्याम् ।")
def rule_6_1_218(ctx=None):
    """
    6.1.218: चड्यन्यतरस्याम् ।
    """
    pass


@registry.register("6.1.219", text="मतोः पूर्वमात् संज्ञायां स्त्रियाम् ।")
def rule_6_1_219(ctx=None):
    """
    6.1.219: मतोः पूर्वमात् संज्ञायां स्त्रियाम् ।
    """
    pass


@registry.register("6.1.220", text="अन्तोऽवत्याः ।")
def rule_6_1_220(ctx=None):
    """
    6.1.220: अन्तोऽवत्याः ।
    """
    pass


@registry.register("6.1.221", text="ईवत्याः ।")
def rule_6_1_221(ctx=None):
    """
    6.1.221: ईवत्याः ।
    """
    pass


@registry.register("6.1.222", text="चौ ।")
def rule_6_1_222(ctx=None):
    """
    6.1.222: चौ ।
    """
    pass


@registry.register("6.1.223", text="समासस्य ।")
def rule_6_1_223(ctx=None):
    """
    6.1.223: समासस्य ।
    """
    pass


@registry.register("6.2.1", text="बहुव्रीहौ प्रकृत्या पूर्वपदम् ।")
def rule_6_2_1(ctx=None):
    """
    6.2.1: बहुव्रीहौ प्रकृत्या पूर्वपदम् ।
    """
    pass


@registry.register("6.2.2", text="तत्पुरुषे तुल्यार्थतृतीयासप्तम्युपमानाव्ययद्वितीयाकृत्याः ।")
def rule_6_2_2(ctx=None):
    """
    6.2.2: तत्पुरुषे तुल्यार्थतृतीयासप्तम्युपमानाव्ययद्वितीयाकृत्याः ।
    """
    pass


@registry.register("6.2.3", text="वर्णः वर्णेष्वनेते ।")
def rule_6_2_3(ctx=None):
    """
    6.2.3: वर्णः वर्णेष्वनेते ।
    """
    pass


@registry.register("6.2.4", text="गाधलवणयोः प्रमाणे ।")
def rule_6_2_4(ctx=None):
    """
    6.2.4: गाधलवणयोः प्रमाणे ।
    """
    pass


@registry.register("6.2.5", text="दायाद्यं दायादे ।")
def rule_6_2_5(ctx=None):
    """
    6.2.5: दायाद्यं दायादे ।
    """
    pass


@registry.register("6.2.6", text="प्रतिबन्धि चिरकृच्छ्रयोः ।")
def rule_6_2_6(ctx=None):
    """
    6.2.6: प्रतिबन्धि चिरकृच्छ्रयोः ।
    """
    pass


@registry.register("6.2.7", text="पदेऽपदेशे ।")
def rule_6_2_7(ctx=None):
    """
    6.2.7: पदेऽपदेशे ।
    """
    pass


@registry.register("6.2.8", text="निवाते वातत्राणे ।")
def rule_6_2_8(ctx=None):
    """
    6.2.8: निवाते वातत्राणे ।
    """
    pass


@registry.register("6.2.9", text="शारदेअनार्तवे ।")
def rule_6_2_9(ctx=None):
    """
    6.2.9: शारदेअनार्तवे ।
    """
    pass


@registry.register("6.2.10", text="अध्वर्युकषाययोर्जातौ ।")
def rule_6_2_10(ctx=None):
    """
    6.2.10: अध्वर्युकषाययोर्जातौ ।
    """
    pass


@registry.register("6.2.11", text="सदृशप्रतिरूपयोः सादृश्ये ।")
def rule_6_2_11(ctx=None):
    """
    6.2.11: सदृशप्रतिरूपयोः सादृश्ये ।
    """
    pass


@registry.register("6.2.12", text="द्विगौ प्रमाणे ।")
def rule_6_2_12(ctx=None):
    """
    6.2.12: द्विगौ प्रमाणे ।
    """
    pass


@registry.register("6.2.13", text="गन्तव्यपण्यं वाणिजे ।")
def rule_6_2_13(ctx=None):
    """
    6.2.13: गन्तव्यपण्यं वाणिजे ।
    """
    pass


@registry.register("6.2.14", text="मात्रोपज्ञोपक्रमच्छाये नपुंसके ।")
def rule_6_2_14(ctx=None):
    """
    6.2.14: मात्रोपज्ञोपक्रमच्छाये नपुंसके ।
    """
    pass


@registry.register("6.2.15", text="सुखप्रिययोर्हिते ।")
def rule_6_2_15(ctx=None):
    """
    6.2.15: सुखप्रिययोर्हिते ।
    """
    pass


@registry.register("6.2.16", text="प्रीतौ च ।")
def rule_6_2_16(ctx=None):
    """
    6.2.16: प्रीतौ च ।
    """
    pass


@registry.register("6.2.17", text="स्वं स्वामिनि ।")
def rule_6_2_17(ctx=None):
    """
    6.2.17: स्वं स्वामिनि ।
    """
    pass


@registry.register("6.2.18", text="पत्यावैश्वर्ये ।")
def rule_6_2_18(ctx=None):
    """
    6.2.18: पत्यावैश्वर्ये ।
    """
    pass


@registry.register("6.2.19", text="न भूवाक्विद्दिधिषु ।")
def rule_6_2_19(ctx=None):
    """
    6.2.19: न भूवाक्विद्दिधिषु ।
    """
    pass


@registry.register("6.2.20", text="वा भुवनम् ।")
def rule_6_2_20(ctx=None):
    """
    6.2.20: वा भुवनम् ।
    """
    pass


@registry.register("6.2.21", text="आशङ्काबाधनेदीयस्सु संभावने ।")
def rule_6_2_21(ctx=None):
    """
    6.2.21: आशङ्काबाधनेदीयस्सु संभावने ।
    """
    pass


@registry.register("6.2.22", text="पूर्वे भूतपूर्वे ।")
def rule_6_2_22(ctx=None):
    """
    6.2.22: पूर्वे भूतपूर्वे ।
    """
    pass


@registry.register("6.2.23", text="सविधसनीडसमर्यादसवेशसदेशेषु सामीप्ये ।")
def rule_6_2_23(ctx=None):
    """
    6.2.23: सविधसनीडसमर्यादसवेशसदेशेषु सामीप्ये ।
    """
    pass


@registry.register("6.2.24", text="विस्पष्टादीनि गुणवचनेषु ।")
def rule_6_2_24(ctx=None):
    """
    6.2.24: विस्पष्टादीनि गुणवचनेषु ।
    """
    pass


@registry.register("6.2.25", text="श्रज्याऽवमकन्पापवत्सु भावे कर्मधारये ।")
def rule_6_2_25(ctx=None):
    """
    6.2.25: श्रज्याऽवमकन्पापवत्सु भावे कर्मधारये ।
    """
    pass


@registry.register("6.2.26", text="कुमारश्च ।")
def rule_6_2_26(ctx=None):
    """
    6.2.26: कुमारश्च ।
    """
    pass


@registry.register("6.2.27", text="आदिः प्रत्येनसि ।")
def rule_6_2_27(ctx=None):
    """
    6.2.27: आदिः प्रत्येनसि ।
    """
    pass


@registry.register("6.2.28", text="पूगेष्वन्यतरस्याम् ।")
def rule_6_2_28(ctx=None):
    """
    6.2.28: पूगेष्वन्यतरस्याम् ।
    """
    pass


@registry.register("6.2.29", text="इगन्तकालकपालभगालशरावेषु द्विगौ ।")
def rule_6_2_29(ctx=None):
    """
    6.2.29: इगन्तकालकपालभगालशरावेषु द्विगौ ।
    """
    pass


@registry.register("6.2.30", text="बह्वन्यतरस्याम् ।")
def rule_6_2_30(ctx=None):
    """
    6.2.30: बह्वन्यतरस्याम् ।
    """
    pass


@registry.register("6.2.31", text="दिष्टिवितस्त्योश्च ।")
def rule_6_2_31(ctx=None):
    """
    6.2.31: दिष्टिवितस्त्योश्च ।
    """
    pass


@registry.register("6.2.32", text="सप्तमी सिद्धशुष्कपक्वबन्धेष्वकालात् ।")
def rule_6_2_32(ctx=None):
    """
    6.2.32: सप्तमी सिद्धशुष्कपक्वबन्धेष्वकालात् ।
    """
    pass


@registry.register("6.2.33", text="परिप्रत्युपापा वर्ज्यमानाहोरात्रावयवेषु ।")
def rule_6_2_33(ctx=None):
    """
    6.2.33: परिप्रत्युपापा वर्ज्यमानाहोरात्रावयवेषु ।
    """
    pass


@registry.register("6.2.34", text="राजन्यबहुवचनद्वंद्वेऽन्धकवृष्णिषु ।")
def rule_6_2_34(ctx=None):
    """
    6.2.34: राजन्यबहुवचनद्वंद्वेऽन्धकवृष्णिषु ।
    """
    pass


@registry.register("6.2.35", text="संख्या ।")
def rule_6_2_35(ctx=None):
    """
    6.2.35: संख्या ।
    """
    pass


@registry.register("6.2.36", text="आचार्योपसर्जनश्चान्तेवासी ।")
def rule_6_2_36(ctx=None):
    """
    6.2.36: आचार्योपसर्जनश्चान्तेवासी ।
    """
    pass


@registry.register("6.2.37", text="कार्तकौजपादयश्च ।")
def rule_6_2_37(ctx=None):
    """
    6.2.37: कार्तकौजपादयश्च ।
    """
    pass


@registry.register("6.2.38", text="महान् व्रीह्यपराह्णगृष्टीष्वासजाबालभारभारतहैलिहिलरौरवप्रवृद्धेषु ।")
def rule_6_2_38(ctx=None):
    """
    6.2.38: महान् व्रीह्यपराह्णगृष्टीष्वासजाबालभारभारतहैलिहिलरौरवप्रवृद्धेषु ।
    """
    pass


@registry.register("6.2.39", text="क्षुल्लकश्च वैश्वदेवे ।")
def rule_6_2_39(ctx=None):
    """
    6.2.39: क्षुल्लकश्च वैश्वदेवे ।
    """
    pass


@registry.register("6.2.40", text="उष्ट्रः सादिवाम्योः ।")
def rule_6_2_40(ctx=None):
    """
    6.2.40: उष्ट्रः सादिवाम्योः ।
    """
    pass


@registry.register("6.2.41", text="गौः सादसादिसारथिषु ।")
def rule_6_2_41(ctx=None):
    """
    6.2.41: गौः सादसादिसारथिषु ।
    """
    pass


@registry.register("6.2.42", text="कुरुगार्हपतरिक्तगुर्वसूतजरत्यश्लीलदृढरूपापारेवडवातैतिलकद्रूःपण्यकम्बलो दासीभाराणां च ।")
def rule_6_2_42(ctx=None):
    """
    6.2.42: कुरुगार्हपतरिक्तगुर्वसूतजरत्यश्लीलदृढरूपापारेवडवातैतिलकद्रूःपण्यकम्बलो दासीभाराणां च ।
    """
    pass


@registry.register("6.2.43", text="चतुर्थी तदर्थे ।")
def rule_6_2_43(ctx=None):
    """
    6.2.43: चतुर्थी तदर्थे ।
    """
    pass


@registry.register("6.2.44", text="अर्थे ।")
def rule_6_2_44(ctx=None):
    """
    6.2.44: अर्थे ।
    """
    pass


@registry.register("6.2.45", text="क्ते च ।")
def rule_6_2_45(ctx=None):
    """
    6.2.45: क्ते च ।
    """
    pass


@registry.register("6.2.46", text="कर्मधारयेऽनिष्ठा ।")
def rule_6_2_46(ctx=None):
    """
    6.2.46: कर्मधारयेऽनिष्ठा ।
    """
    pass


@registry.register("6.2.47", text="अहीने द्वितीया ।")
def rule_6_2_47(ctx=None):
    """
    6.2.47: अहीने द्वितीया ।
    """
    pass


@registry.register("6.2.48", text="तृतीया कर्मणि ।")
def rule_6_2_48(ctx=None):
    """
    6.2.48: तृतीया कर्मणि ।
    """
    pass


@registry.register("6.2.49", text="गतिरनन्तरः ।")
def rule_6_2_49(ctx=None):
    """
    6.2.49: गतिरनन्तरः ।
    """
    pass


@registry.register("6.2.50", text="तादौ च निति कृत्यतौ ।")
def rule_6_2_50(ctx=None):
    """
    6.2.50: तादौ च निति कृत्यतौ ।
    """
    pass


@registry.register("6.2.51", text="तवै चान्तश्च युगपत् ।")
def rule_6_2_51(ctx=None):
    """
    6.2.51: तवै चान्तश्च युगपत् ।
    """
    pass


@registry.register("6.2.52", text="अनिगन्तोऽञ्श्चतौ वप्रत्यये ।")
def rule_6_2_52(ctx=None):
    """
    6.2.52: अनिगन्तोऽञ्श्चतौ वप्रत्यये ।
    """
    pass


@registry.register("6.2.53", text="न्यधी च ।")
def rule_6_2_53(ctx=None):
    """
    6.2.53: न्यधी च ।
    """
    pass


@registry.register("6.2.54", text="ईषदन्यतरस्याम् ।")
def rule_6_2_54(ctx=None):
    """
    6.2.54: ईषदन्यतरस्याम् ।
    """
    pass


@registry.register("6.2.55", text="हिरण्यपरिमाणं धने ।")
def rule_6_2_55(ctx=None):
    """
    6.2.55: हिरण्यपरिमाणं धने ।
    """
    pass


@registry.register("6.2.56", text="प्रथमोऽचिरोपसम्पत्तौ ।")
def rule_6_2_56(ctx=None):
    """
    6.2.56: प्रथमोऽचिरोपसम्पत्तौ ।
    """
    pass


@registry.register("6.2.57", text="कतरकतमौ कर्मधारये ।")
def rule_6_2_57(ctx=None):
    """
    6.2.57: कतरकतमौ कर्मधारये ।
    """
    pass


@registry.register("6.2.58", text="आर्यो ब्राह्मणकुमारयोः ।")
def rule_6_2_58(ctx=None):
    """
    6.2.58: आर्यो ब्राह्मणकुमारयोः ।
    """
    pass


@registry.register("6.2.59", text="राजा च ।")
def rule_6_2_59(ctx=None):
    """
    6.2.59: राजा च ।
    """
    pass


@registry.register("6.2.60", text="षष्ठी प्रत्येनसि ।")
def rule_6_2_60(ctx=None):
    """
    6.2.60: षष्ठी प्रत्येनसि ।
    """
    pass


@registry.register("6.2.61", text="क्ते नित्यार्थे ।")
def rule_6_2_61(ctx=None):
    """
    6.2.61: क्ते नित्यार्थे ।
    """
    pass


@registry.register("6.2.62", text="ग्रामः शिल्पिनि ।")
def rule_6_2_62(ctx=None):
    """
    6.2.62: ग्रामः शिल्पिनि ।
    """
    pass


@registry.register("6.2.63", text="राजा च प्रशंसायाम् ।")
def rule_6_2_63(ctx=None):
    """
    6.2.63: राजा च प्रशंसायाम् ।
    """
    pass


@registry.register("6.2.64", text="आदिरुदात्तः ।")
def rule_6_2_64(ctx=None):
    """
    6.2.64: आदिरुदात्तः ।
    """
    pass


@registry.register("6.2.65", text="सप्तमीहारिणौ धर्येऽहरणे ।")
def rule_6_2_65(ctx=None):
    """
    6.2.65: सप्तमीहारिणौ धर्येऽहरणे ।
    """
    pass


@registry.register("6.2.66", text="युक्ते च ।")
def rule_6_2_66(ctx=None):
    """
    6.2.66: युक्ते च ।
    """
    pass


@registry.register("6.2.67", text="विभाषाऽध्यक्षे ।")
def rule_6_2_67(ctx=None):
    """
    6.2.67: विभाषाऽध्यक्षे ।
    """
    pass


@registry.register("6.2.68", text="पापं च शिल्पिनि ।")
def rule_6_2_68(ctx=None):
    """
    6.2.68: पापं च शिल्पिनि ।
    """
    pass


@registry.register("6.2.69", text="गोत्रान्तेवासिमाणवब्राह्मणेषु क्षेपे ।")
def rule_6_2_69(ctx=None):
    """
    6.2.69: गोत्रान्तेवासिमाणवब्राह्मणेषु क्षेपे ।
    """
    pass


@registry.register("6.2.70", text="अङ्गानि मैरेये ।")
def rule_6_2_70(ctx=None):
    """
    6.2.70: अङ्गानि मैरेये ।
    """
    pass


@registry.register("6.2.71", text="भक्ताख्यास्तदर्थेषु ।")
def rule_6_2_71(ctx=None):
    """
    6.2.71: भक्ताख्यास्तदर्थेषु ।
    """
    pass


@registry.register("6.2.72", text="गोबिडालसिंहसैन्धवेषूपमाने ।")
def rule_6_2_72(ctx=None):
    """
    6.2.72: गोबिडालसिंहसैन्धवेषूपमाने ।
    """
    pass


@registry.register("6.2.73", text="अके जीविकाऽर्थे ।")
def rule_6_2_73(ctx=None):
    """
    6.2.73: अके जीविकाऽर्थे ।
    """
    pass


@registry.register("6.2.74", text="प्राचां क्रीडायाम् ।")
def rule_6_2_74(ctx=None):
    """
    6.2.74: प्राचां क्रीडायाम् ।
    """
    pass


@registry.register("6.2.75", text="अणि नियुक्ते ।")
def rule_6_2_75(ctx=None):
    """
    6.2.75: अणि नियुक्ते ।
    """
    pass


@registry.register("6.2.76", text="शिल्पिनि चाकृञः ।")
def rule_6_2_76(ctx=None):
    """
    6.2.76: शिल्पिनि चाकृञः ।
    """
    pass


@registry.register("6.2.77", text="संज्ञायां च ।")
def rule_6_2_77(ctx=None):
    """
    6.2.77: संज्ञायां च ।
    """
    pass


@registry.register("6.2.78", text="गोतन्तियवं पाले ।")
def rule_6_2_78(ctx=None):
    """
    6.2.78: गोतन्तियवं पाले ।
    """
    pass


@registry.register("6.2.79", text="णिनि ।")
def rule_6_2_79(ctx=None):
    """
    6.2.79: णिनि ।
    """
    pass


@registry.register("6.2.80", text="उपमानं शब्दार्थप्रकृतावेव ।")
def rule_6_2_80(ctx=None):
    """
    6.2.80: उपमानं शब्दार्थप्रकृतावेव ।
    """
    pass


@registry.register("6.2.81", text="युक्तारोह्यादयश्च ।")
def rule_6_2_81(ctx=None):
    """
    6.2.81: युक्तारोह्यादयश्च ।
    """
    pass


@registry.register("6.2.82", text="दीर्घकाशतुषभ्राष्ट्रवटं जे ।")
def rule_6_2_82(ctx=None):
    """
    6.2.82: दीर्घकाशतुषभ्राष्ट्रवटं जे ।
    """
    pass


@registry.register("6.2.83", text="अन्त्यात् पूर्वं बह्वचः ।")
def rule_6_2_83(ctx=None):
    """
    6.2.83: अन्त्यात् पूर्वं बह्वचः ।
    """
    pass


@registry.register("6.2.84", text="ग्रामेऽनिवसन्तः ।")
def rule_6_2_84(ctx=None):
    """
    6.2.84: ग्रामेऽनिवसन्तः ।
    """
    pass


@registry.register("6.2.85", text="घोषादिषु ।")
def rule_6_2_85(ctx=None):
    """
    6.2.85: घोषादिषु ।
    """
    pass


@registry.register("6.2.86", text="छात्र्यादयः शालायाम् ।")
def rule_6_2_86(ctx=None):
    """
    6.2.86: छात्र्यादयः शालायाम् ।
    """
    pass


@registry.register("6.2.87", text="प्रस्थेऽवृद्धमकर्त्यादीनाम् ।")
def rule_6_2_87(ctx=None):
    """
    6.2.87: प्रस्थेऽवृद्धमकर्त्यादीनाम् ।
    """
    pass


@registry.register("6.2.88", text="मालाऽऽदीनां च ।")
def rule_6_2_88(ctx=None):
    """
    6.2.88: मालाऽऽदीनां च ।
    """
    pass


@registry.register("6.2.89", text="अमहन्नवं नगरेऽनुदीचाम् ।")
def rule_6_2_89(ctx=None):
    """
    6.2.89: अमहन्नवं नगरेऽनुदीचाम् ।
    """
    pass


@registry.register("6.2.90", text="अर्मे चावर्णं व्यच्त्र्यच् ।")
def rule_6_2_90(ctx=None):
    """
    6.2.90: अर्मे चावर्णं व्यच्त्र्यच् ।
    """
    pass


@registry.register("6.2.91", text="न भूताधिकसंजीवमद्राश्मकज्ञ्जलम् ।")
def rule_6_2_91(ctx=None):
    """
    6.2.91: न भूताधिकसंजीवमद्राश्मकज्ञ्जलम् ।
    """
    pass


@registry.register("6.2.92", text="अन्तः ।")
def rule_6_2_92(ctx=None):
    """
    6.2.92: अन्तः ।
    """
    pass


@registry.register("6.2.93", text="सर्वं गुणकार्ये ।")
def rule_6_2_93(ctx=None):
    """
    6.2.93: सर्वं गुणकार्ये ।
    """
    pass


@registry.register("6.2.94", text="संज्ञायां गिरिनिकाययोः ।")
def rule_6_2_94(ctx=None):
    """
    6.2.94: संज्ञायां गिरिनिकाययोः ।
    """
    pass


@registry.register("6.2.95", text="कुमार्यां वयसि ।")
def rule_6_2_95(ctx=None):
    """
    6.2.95: कुमार्यां वयसि ।
    """
    pass


@registry.register("6.2.96", text="उदकेऽकेवले ।")
def rule_6_2_96(ctx=None):
    """
    6.2.96: उदकेऽकेवले ।
    """
    pass


@registry.register("6.2.97", text="द्विगौ क्रतौ ।")
def rule_6_2_97(ctx=None):
    """
    6.2.97: द्विगौ क्रतौ ।
    """
    pass


@registry.register("6.2.98", text="सभायां नपुंसके ।")
def rule_6_2_98(ctx=None):
    """
    6.2.98: सभायां नपुंसके ।
    """
    pass


@registry.register("6.2.99", text="पुरे प्राचाम् ।")
def rule_6_2_99(ctx=None):
    """
    6.2.99: पुरे प्राचाम् ।
    """
    pass


@registry.register("6.2.100", text="अरिष्टगौडपूर्वे च ।")
def rule_6_2_100(ctx=None):
    """
    6.2.100: अरिष्टगौडपूर्वे च ।
    """
    pass


@registry.register("6.2.101", text="न हास्तिनफलकमार्देयाः ।")
def rule_6_2_101(ctx=None):
    """
    6.2.101: न हास्तिनफलकमार्देयाः ।
    """
    pass


@registry.register("6.2.102", text="कुसूलकूपकुम्भशालं बिले ।")
def rule_6_2_102(ctx=None):
    """
    6.2.102: कुसूलकूपकुम्भशालं बिले ।
    """
    pass


@registry.register("6.2.103", text="दिक्शब्दा ग्रामजनपदाख्यानचानराटेषु ।")
def rule_6_2_103(ctx=None):
    """
    6.2.103: दिक्शब्दा ग्रामजनपदाख्यानचानराटेषु ।
    """
    pass


@registry.register("6.2.104", text="आचार्योपसर्जनश्चान्तेवासिनि ।")
def rule_6_2_104(ctx=None):
    """
    6.2.104: आचार्योपसर्जनश्चान्तेवासिनि ।
    """
    pass


@registry.register("6.2.105", text="उत्तरपदवृद्धौ सर्वं च ।")
def rule_6_2_105(ctx=None):
    """
    6.2.105: उत्तरपदवृद्धौ सर्वं च ।
    """
    pass


@registry.register("6.2.106", text="बहुव्रीहौ विश्वं संज्ञयाम् ।")
def rule_6_2_106(ctx=None):
    """
    6.2.106: बहुव्रीहौ विश्वं संज्ञयाम् ।
    """
    pass


@registry.register("6.2.107", text="उदराश्वेषुषु ।")
def rule_6_2_107(ctx=None):
    """
    6.2.107: उदराश्वेषुषु ।
    """
    pass


@registry.register("6.2.108", text="क्षेपे ।")
def rule_6_2_108(ctx=None):
    """
    6.2.108: क्षेपे ।
    """
    pass


@registry.register("6.2.109", text="नदी बन्धुनि ।")
def rule_6_2_109(ctx=None):
    """
    6.2.109: नदी बन्धुनि ।
    """
    pass


@registry.register("6.2.110", text="निष्ठोपसर्गपूर्वमन्यतरस्याम् ।")
def rule_6_2_110(ctx=None):
    """
    6.2.110: निष्ठोपसर्गपूर्वमन्यतरस्याम् ।
    """
    pass


@registry.register("6.2.111", text="उत्तरपदादिः ।")
def rule_6_2_111(ctx=None):
    """
    6.2.111: उत्तरपदादिः ।
    """
    pass


@registry.register("6.2.112", text="कर्णो वर्णलक्षणात् ।")
def rule_6_2_112(ctx=None):
    """
    6.2.112: कर्णो वर्णलक्षणात् ।
    """
    pass


@registry.register("6.2.113", text="संज्ञौपम्ययोश्च ।")
def rule_6_2_113(ctx=None):
    """
    6.2.113: संज्ञौपम्ययोश्च ।
    """
    pass


@registry.register("6.2.114", text="कण्ठपृष्ठग्रीवाजंघं च ।")
def rule_6_2_114(ctx=None):
    """
    6.2.114: कण्ठपृष्ठग्रीवाजंघं च ।
    """
    pass


@registry.register("6.2.115", text="शृङ्गमवस्थायां च ।")
def rule_6_2_115(ctx=None):
    """
    6.2.115: शृङ्गमवस्थायां च ।
    """
    pass


@registry.register("6.2.116", text="जरमरमित्रमृताः ।")
def rule_6_2_116(ctx=None):
    """
    6.2.116: जरमरमित्रमृताः ।
    """
    pass


@registry.register("6.2.117", text="सोर्मनसी अलोमोषसी ।")
def rule_6_2_117(ctx=None):
    """
    6.2.117: सोर्मनसी अलोमोषसी ।
    """
    pass


@registry.register("6.2.118", text="क्रत्वादयश्च ।")
def rule_6_2_118(ctx=None):
    """
    6.2.118: क्रत्वादयश्च ।
    """
    pass


@registry.register("6.2.119", text="आद्युदात्तं व्यच् छन्दसि ।")
def rule_6_2_119(ctx=None):
    """
    6.2.119: आद्युदात्तं व्यच् छन्दसि ।
    """
    pass


@registry.register("6.2.120", text="वीरवीर्यौ च ।")
def rule_6_2_120(ctx=None):
    """
    6.2.120: वीरवीर्यौ च ।
    """
    pass


@registry.register("6.2.121", text="कूलतीरतूलमूलशालाऽक्षसममव्ययीभावे ।")
def rule_6_2_121(ctx=None):
    """
    6.2.121: कूलतीरतूलमूलशालाऽक्षसममव्ययीभावे ।
    """
    pass


@registry.register("6.2.122", text="कंसमन्थशूर्पपाय्यकाण्डं द्विगौ ।")
def rule_6_2_122(ctx=None):
    """
    6.2.122: कंसमन्थशूर्पपाय्यकाण्डं द्विगौ ।
    """
    pass


@registry.register("6.2.123", text="तत्पुरुषे शालायां नपुंसके ।")
def rule_6_2_123(ctx=None):
    """
    6.2.123: तत्पुरुषे शालायां नपुंसके ।
    """
    pass


@registry.register("6.2.124", text="कन्था च ।")
def rule_6_2_124(ctx=None):
    """
    6.2.124: कन्था च ।
    """
    pass


@registry.register("6.2.125", text="आदिश्चिहणादीनाम् ।")
def rule_6_2_125(ctx=None):
    """
    6.2.125: आदिश्चिहणादीनाम् ।
    """
    pass


@registry.register("6.2.126", text="चेलखेटकटुककाण्डं गर्हायाम् ।")
def rule_6_2_126(ctx=None):
    """
    6.2.126: चेलखेटकटुककाण्डं गर्हायाम् ।
    """
    pass


@registry.register("6.2.127", text="चीरमुपमानम् ।")
def rule_6_2_127(ctx=None):
    """
    6.2.127: चीरमुपमानम् ।
    """
    pass


@registry.register("6.2.128", text="पललसूपशाकं मिश्रे ।")
def rule_6_2_128(ctx=None):
    """
    6.2.128: पललसूपशाकं मिश्रे ।
    """
    pass


@registry.register("6.2.129", text="कूलसूदस्थलकर्षाः संज्ञायाम् ।")
def rule_6_2_129(ctx=None):
    """
    6.2.129: कूलसूदस्थलकर्षाः संज्ञायाम् ।
    """
    pass


@registry.register("6.2.130", text="अकर्मधारये राज्यम् ।")
def rule_6_2_130(ctx=None):
    """
    6.2.130: अकर्मधारये राज्यम् ।
    """
    pass


@registry.register("6.2.131", text="वर्गादयश्च ।")
def rule_6_2_131(ctx=None):
    """
    6.2.131: वर्गादयश्च ।
    """
    pass


@registry.register("6.2.132", text="पुत्रः पुंभ्यः ।")
def rule_6_2_132(ctx=None):
    """
    6.2.132: पुत्रः पुंभ्यः ।
    """
    pass


@registry.register("6.2.133", text="नाचार्यराजर्विक्संयुक्तज्ञात्याख्येभ्यः ।")
def rule_6_2_133(ctx=None):
    """
    6.2.133: नाचार्यराजर्विक्संयुक्तज्ञात्याख्येभ्यः ।
    """
    pass


@registry.register("6.2.134", text="चूर्णादीन्यप्राणिषष्ठ्ठयाः ।")
def rule_6_2_134(ctx=None):
    """
    6.2.134: चूर्णादीन्यप्राणिषष्ठ्ठयाः ।
    """
    pass


@registry.register("6.2.135", text="षट् च काण्डादीनि ।")
def rule_6_2_135(ctx=None):
    """
    6.2.135: षट् च काण्डादीनि ।
    """
    pass


@registry.register("6.2.136", text="कुण्डं वनम् ।")
def rule_6_2_136(ctx=None):
    """
    6.2.136: कुण्डं वनम् ।
    """
    pass


@registry.register("6.2.137", text="प्रकृत्या भगालम् ।")
def rule_6_2_137(ctx=None):
    """
    6.2.137: प्रकृत्या भगालम् ।
    """
    pass


@registry.register("6.2.138", text="शितेर्नित्याबह्वज्बहुव्रीहावभसत् ।")
def rule_6_2_138(ctx=None):
    """
    6.2.138: शितेर्नित्याबह्वज्बहुव्रीहावभसत् ।
    """
    pass


@registry.register("6.2.139", text="गतिकारकोपपदात् कृत् ।")
def rule_6_2_139(ctx=None):
    """
    6.2.139: गतिकारकोपपदात् कृत् ।
    """
    pass


@registry.register("6.2.140", text="उभे वनस्पत्यादिषु युगपत् ।")
def rule_6_2_140(ctx=None):
    """
    6.2.140: उभे वनस्पत्यादिषु युगपत् ।
    """
    pass


@registry.register("6.2.141", text="देवताद्वंद्वे च ।")
def rule_6_2_141(ctx=None):
    """
    6.2.141: देवताद्वंद्वे च ।
    """
    pass


@registry.register("6.2.142", text="नोत्तरपदेऽनुदात्तादावपृथिवीरुद्रपूषमन्थिषु ।")
def rule_6_2_142(ctx=None):
    """
    6.2.142: नोत्तरपदेऽनुदात्तादावपृथिवीरुद्रपूषमन्थिषु ।
    """
    pass


@registry.register("6.2.143", text="अन्तः ।")
def rule_6_2_143(ctx=None):
    """
    6.2.143: अन्तः ।
    """
    pass


@registry.register("6.2.144", text="थाथघङ्काजबित्रकाणाम् ।")
def rule_6_2_144(ctx=None):
    """
    6.2.144: थाथघङ्काजबित्रकाणाम् ।
    """
    pass


@registry.register("6.2.145", text="सूपमानात् क्तः ।")
def rule_6_2_145(ctx=None):
    """
    6.2.145: सूपमानात् क्तः ।
    """
    pass


@registry.register("6.2.146", text="संज्ञायामनाचितादीनाम् ।")
def rule_6_2_146(ctx=None):
    """
    6.2.146: संज्ञायामनाचितादीनाम् ।
    """
    pass


@registry.register("6.2.147", text="प्रवृद्धादीनां च ।")
def rule_6_2_147(ctx=None):
    """
    6.2.147: प्रवृद्धादीनां च ।
    """
    pass


@registry.register("6.2.148", text="कारकाद्दत्तश्रुतयोरेवाशिषि ।")
def rule_6_2_148(ctx=None):
    """
    6.2.148: कारकाद्दत्तश्रुतयोरेवाशिषि ।
    """
    pass


@registry.register("6.2.149", text="इत्थम्भूतेन कृतमिति च ।")
def rule_6_2_149(ctx=None):
    """
    6.2.149: इत्थम्भूतेन कृतमिति च ।
    """
    pass


@registry.register("6.2.150", text="अनो भावकर्मवचनः ।")
def rule_6_2_150(ctx=None):
    """
    6.2.150: अनो भावकर्मवचनः ।
    """
    pass


@registry.register("6.2.151", text="मन्क्तिन्व्याख्यानशयनासनस्थानयाजकादिक्रीताः ।")
def rule_6_2_151(ctx=None):
    """
    6.2.151: मन्क्तिन्व्याख्यानशयनासनस्थानयाजकादिक्रीताः ।
    """
    pass


@registry.register("6.2.152", text="सप्तम्याः पुण्यम् ।")
def rule_6_2_152(ctx=None):
    """
    6.2.152: सप्तम्याः पुण्यम् ।
    """
    pass


@registry.register("6.2.153", text="ऊनार्थकलहं तृतीयायाः ।")
def rule_6_2_153(ctx=None):
    """
    6.2.153: ऊनार्थकलहं तृतीयायाः ।
    """
    pass


@registry.register("6.2.154", text="मिश्र चानुपसर्गमसंधौ ।")
def rule_6_2_154(ctx=None):
    """
    6.2.154: मिश्र चानुपसर्गमसंधौ ।
    """
    pass


@registry.register("6.2.155", text="नो गुणप्रतिषेधे सम्पाद्यर्हहितालमर्थास्तद्धिताः ।")
def rule_6_2_155(ctx=None):
    """
    6.2.155: नो गुणप्रतिषेधे सम्पाद्यर्हहितालमर्थास्तद्धिताः ।
    """
    pass


@registry.register("6.2.156", text="ययतोश्चातदर्थे ।")
def rule_6_2_156(ctx=None):
    """
    6.2.156: ययतोश्चातदर्थे ।
    """
    pass


@registry.register("6.2.157", text="अच्कावशक्तौ ।")
def rule_6_2_157(ctx=None):
    """
    6.2.157: अच्कावशक्तौ ।
    """
    pass


@registry.register("6.2.158", text="आक्रोशे च ।")
def rule_6_2_158(ctx=None):
    """
    6.2.158: आक्रोशे च ।
    """
    pass


@registry.register("6.2.159", text="संज्ञायाम् ।")
def rule_6_2_159(ctx=None):
    """
    6.2.159: संज्ञायाम् ।
    """
    pass


@registry.register("6.2.160", text="कृत्योकेष्णुच्चार्वादयश्च ।")
def rule_6_2_160(ctx=None):
    """
    6.2.160: कृत्योकेष्णुच्चार्वादयश्च ।
    """
    pass


@registry.register("6.2.161", text="विभाषा तृन्नन्नतीक्ष्णशुचिषु ।")
def rule_6_2_161(ctx=None):
    """
    6.2.161: विभाषा तृन्नन्नतीक्ष्णशुचिषु ।
    """
    pass


@registry.register("6.2.162", text="बहुव्रीहाविदमेतत्तद्भ्यः प्रथमपूरणयोः क्रियागणने ।")
def rule_6_2_162(ctx=None):
    """
    6.2.162: बहुव्रीहाविदमेतत्तद्भ्यः प्रथमपूरणयोः क्रियागणने ।
    """
    pass


@registry.register("6.2.163", text="संख्यायाः स्तनः ।")
def rule_6_2_163(ctx=None):
    """
    6.2.163: संख्यायाः स्तनः ।
    """
    pass


@registry.register("6.2.164", text="विभाषा छन्दसि ।")
def rule_6_2_164(ctx=None):
    """
    6.2.164: विभाषा छन्दसि ।
    """
    pass


@registry.register("6.2.165", text="संज्ञायां मित्राजिनयोः ।")
def rule_6_2_165(ctx=None):
    """
    6.2.165: संज्ञायां मित्राजिनयोः ।
    """
    pass


@registry.register("6.2.166", text="व्यवायिनोऽन्तरम् ।")
def rule_6_2_166(ctx=None):
    """
    6.2.166: व्यवायिनोऽन्तरम् ।
    """
    pass


@registry.register("6.2.167", text="मुखं स्वाङ्गम् ।")
def rule_6_2_167(ctx=None):
    """
    6.2.167: मुखं स्वाङ्गम् ।
    """
    pass


@registry.register("6.2.168", text="नाव्ययदिक्शब्दगोमहत्स्थूलमुष्टिपृथुवत्सेभ्यः ।")
def rule_6_2_168(ctx=None):
    """
    6.2.168: नाव्ययदिक्शब्दगोमहत्स्थूलमुष्टिपृथुवत्सेभ्यः ।
    """
    pass


@registry.register("6.2.169", text="निष्ठोपमानादन्यतरस्याम् ।")
def rule_6_2_169(ctx=None):
    """
    6.2.169: निष्ठोपमानादन्यतरस्याम् ।
    """
    pass


@registry.register("6.2.170", text="जातिकालसुखादिभ्योऽनाच्छादनात् क्तोऽकृतमितप्रतिपन्नाः ।")
def rule_6_2_170(ctx=None):
    """
    6.2.170: जातिकालसुखादिभ्योऽनाच्छादनात् क्तोऽकृतमितप्रतिपन्नाः ।
    """
    pass


@registry.register("6.2.171", text="वा जाते ।")
def rule_6_2_171(ctx=None):
    """
    6.2.171: वा जाते ।
    """
    pass


@registry.register("6.2.172", text="नञ्सुभ्याम् ।")
def rule_6_2_172(ctx=None):
    """
    6.2.172: नञ्सुभ्याम् ।
    """
    pass


@registry.register("6.2.173", text="कपि पूर्वम् ।")
def rule_6_2_173(ctx=None):
    """
    6.2.173: कपि पूर्वम् ।
    """
    pass


@registry.register("6.2.174", text="ह्रस्वान्तेऽन्त्यात् पूर्वम् ।")
def rule_6_2_174(ctx=None):
    """
    6.2.174: ह्रस्वान्तेऽन्त्यात् पूर्वम् ।
    """
    pass


@registry.register("6.2.175", text="बहोर्नञ्वदुत्तरपदभूम्नि ।")
def rule_6_2_175(ctx=None):
    """
    6.2.175: बहोर्नञ्वदुत्तरपदभूम्नि ।
    """
    pass


@registry.register("6.2.176", text="न गुणादयोऽवयवाः ।")
def rule_6_2_176(ctx=None):
    """
    6.2.176: न गुणादयोऽवयवाः ।
    """
    pass


@registry.register("6.2.177", text="उपसर्गात् स्वाङ्गं ध्रुवमपर्शु ।")
def rule_6_2_177(ctx=None):
    """
    6.2.177: उपसर्गात् स्वाङ्गं ध्रुवमपर्शु ।
    """
    pass


@registry.register("6.2.178", text="वनं समासे ।")
def rule_6_2_178(ctx=None):
    """
    6.2.178: वनं समासे ।
    """
    pass


@registry.register("6.2.179", text="अन्तः ।")
def rule_6_2_179(ctx=None):
    """
    6.2.179: अन्तः ।
    """
    pass


@registry.register("6.2.180", text="अन्तश्च ।")
def rule_6_2_180(ctx=None):
    """
    6.2.180: अन्तश्च ।
    """
    pass


@registry.register("6.2.181", text="न निविभ्याम् ।")
def rule_6_2_181(ctx=None):
    """
    6.2.181: न निविभ्याम् ।
    """
    pass


@registry.register("6.2.182", text="परेरभितोभाविमण्डलम् ।")
def rule_6_2_182(ctx=None):
    """
    6.2.182: परेरभितोभाविमण्डलम् ।
    """
    pass


@registry.register("6.2.183", text="प्रादस्वाङ्गं संज्ञायाम् ।")
def rule_6_2_183(ctx=None):
    """
    6.2.183: प्रादस्वाङ्गं संज्ञायाम् ।
    """
    pass


@registry.register("6.2.184", text="निरुदकादीनि च ।")
def rule_6_2_184(ctx=None):
    """
    6.2.184: निरुदकादीनि च ।
    """
    pass


@registry.register("6.2.185", text="अभेर्मुखम् ।")
def rule_6_2_185(ctx=None):
    """
    6.2.185: अभेर्मुखम् ।
    """
    pass


@registry.register("6.2.186", text="अपाच्च ।")
def rule_6_2_186(ctx=None):
    """
    6.2.186: अपाच्च ।
    """
    pass


@registry.register("6.2.187", text="स्फिगपूतवीणा ऽञ्जओ ऽध्वकुक्षिसीरनामनाम च ।")
def rule_6_2_187(ctx=None):
    """
    6.2.187: स्फिगपूतवीणा ऽञ्जओ ऽध्वकुक्षिसीरनामनाम च ।
    """
    pass


@registry.register("6.2.188", text="अधेरुपरिस्थम् ।")
def rule_6_2_188(ctx=None):
    """
    6.2.188: अधेरुपरिस्थम् ।
    """
    pass


@registry.register("6.2.189", text="अनोरप्रधानकनीयसी ।")
def rule_6_2_189(ctx=None):
    """
    6.2.189: अनोरप्रधानकनीयसी ।
    """
    pass


@registry.register("6.2.190", text="पुरुषश्चान्वादिष्टः ।")
def rule_6_2_190(ctx=None):
    """
    6.2.190: पुरुषश्चान्वादिष्टः ।
    """
    pass


@registry.register("6.2.191", text="अतेरकृत्पदे ।")
def rule_6_2_191(ctx=None):
    """
    6.2.191: अतेरकृत्पदे ।
    """
    pass


@registry.register("6.2.192", text="नेरनिधाने ।")
def rule_6_2_192(ctx=None):
    """
    6.2.192: नेरनिधाने ।
    """
    pass


@registry.register("6.2.193", text="प्रतेरंश्वादयस्तत्पुरुषे ।")
def rule_6_2_193(ctx=None):
    """
    6.2.193: प्रतेरंश्वादयस्तत्पुरुषे ।
    """
    pass


@registry.register("6.2.194", text="उपाद् व्यजजिनमगौरादयः ।")
def rule_6_2_194(ctx=None):
    """
    6.2.194: उपाद् व्यजजिनमगौरादयः ।
    """
    pass


@registry.register("6.2.195", text="सोरवक्षेपणे ।")
def rule_6_2_195(ctx=None):
    """
    6.2.195: सोरवक्षेपणे ।
    """
    pass


@registry.register("6.2.196", text="विभाषोत्पुच्छे ।")
def rule_6_2_196(ctx=None):
    """
    6.2.196: विभाषोत्पुच्छे ।
    """
    pass


@registry.register("6.2.197", text="द्वित्रिभ्यां पाद्दन्मूर्धसु बहुव्रीहौ ।")
def rule_6_2_197(ctx=None):
    """
    6.2.197: द्वित्रिभ्यां पाद्दन्मूर्धसु बहुव्रीहौ ।
    """
    pass


@registry.register("6.2.198", text="सक्थं चाक्रान्तात् ।")
def rule_6_2_198(ctx=None):
    """
    6.2.198: सक्थं चाक्रान्तात् ।
    """
    pass


@registry.register("6.2.199", text="परादिश्छन्दसि बहुलम् ।")
def rule_6_2_199(ctx=None):
    """
    6.2.199: परादिश्छन्दसि बहुलम् ।
    """
    pass


@registry.register("6.3.1", text="अलुगुत्तरपदे ।")
def rule_6_3_1(ctx=None):
    """
    6.3.1: अलुगुत्तरपदे ।
    """
    pass


@registry.register("6.3.2", text="पञ्चम्याः स्तोकादिभ्यः ।")
def rule_6_3_2(ctx=None):
    """
    6.3.2: पञ्चम्याः स्तोकादिभ्यः ।
    """
    pass


@registry.register("6.3.3", text="ओजःसहोऽम्भस्तमसः तृतीयायाः ।")
def rule_6_3_3(ctx=None):
    """
    6.3.3: ओजःसहोऽम्भस्तमसः तृतीयायाः ।
    """
    pass


@registry.register("6.3.4", text="मनसः संज्ञायाम् ।")
def rule_6_3_4(ctx=None):
    """
    6.3.4: मनसः संज्ञायाम् ।
    """
    pass


@registry.register("6.3.5", text="आज्ञायिनि च ।")
def rule_6_3_5(ctx=None):
    """
    6.3.5: आज्ञायिनि च ।
    """
    pass


@registry.register("6.3.6", text="आत्मनश्च पूरणे ।")
def rule_6_3_6(ctx=None):
    """
    6.3.6: आत्मनश्च पूरणे ।
    """
    pass


@registry.register("6.3.7", text="वैयाकरणाख्यायां चतुर्थ्याः ।")
def rule_6_3_7(ctx=None):
    """
    6.3.7: वैयाकरणाख्यायां चतुर्थ्याः ।
    """
    pass


@registry.register("6.3.8", text="परस्य च ।")
def rule_6_3_8(ctx=None):
    """
    6.3.8: परस्य च ।
    """
    pass


@registry.register("6.3.9", text="हलदन्तात् सप्तम्याः संज्ञायाम् ।")
def rule_6_3_9(ctx=None):
    """
    6.3.9: हलदन्तात् सप्तम्याः संज्ञायाम् ।
    """
    pass


@registry.register("6.3.10", text="कारनाम्नि च प्राचां हलादौ ।")
def rule_6_3_10(ctx=None):
    """
    6.3.10: कारनाम्नि च प्राचां हलादौ ।
    """
    pass


@registry.register("6.3.11", text="मध्याद्गुरौ ।")
def rule_6_3_11(ctx=None):
    """
    6.3.11: मध्याद्गुरौ ।
    """
    pass


@registry.register("6.3.12", text="अमूर्धमस्तकात् स्वाङ्गादकामे ।")
def rule_6_3_12(ctx=None):
    """
    6.3.12: अमूर्धमस्तकात् स्वाङ्गादकामे ।
    """
    pass


@registry.register("6.3.13", text="बन्धे च विभाषा ।")
def rule_6_3_13(ctx=None):
    """
    6.3.13: बन्धे च विभाषा ।
    """
    pass


@registry.register("6.3.14", text="तत्पुरुषे कृति बहुलम् ।")
def rule_6_3_14(ctx=None):
    """
    6.3.14: तत्पुरुषे कृति बहुलम् ।
    """
    pass


@registry.register("6.3.15", text="प्रावृङ्गरत्कालदिवां जे ।")
def rule_6_3_15(ctx=None):
    """
    6.3.15: प्रावृङ्गरत्कालदिवां जे ।
    """
    pass


@registry.register("6.3.16", text="विभाषा वर्षक्षरशरवरात् ।")
def rule_6_3_16(ctx=None):
    """
    6.3.16: विभाषा वर्षक्षरशरवरात् ।
    """
    pass


@registry.register("6.3.17", text="घकालतनेषु कालनाम्नः ।")
def rule_6_3_17(ctx=None):
    """
    6.3.17: घकालतनेषु कालनाम्नः ।
    """
    pass


@registry.register("6.3.18", text="शयवासवासिषु अकालात् ।")
def rule_6_3_18(ctx=None):
    """
    6.3.18: शयवासवासिषु अकालात् ।
    """
    pass


@registry.register("6.3.19", text="नेन्सिद्धबघ्नातिषु ।")
def rule_6_3_19(ctx=None):
    """
    6.3.19: नेन्सिद्धबघ्नातिषु ।
    """
    pass


@registry.register("6.3.20", text="स्थे च भाषायाम् ।")
def rule_6_3_20(ctx=None):
    """
    6.3.20: स्थे च भाषायाम् ।
    """
    pass


@registry.register("6.3.21", text="षष्ठ्या आक्रोशे ।")
def rule_6_3_21(ctx=None):
    """
    6.3.21: षष्ठ्या आक्रोशे ।
    """
    pass


@registry.register("6.3.22", text="पुत्रेऽन्यतरस्याम् ।")
def rule_6_3_22(ctx=None):
    """
    6.3.22: पुत्रेऽन्यतरस्याम् ।
    """
    pass


@registry.register("6.3.23", text="ऋतो विद्यायोनिसम्बन्धेभ्यः ।")
def rule_6_3_23(ctx=None):
    """
    6.3.23: ऋतो विद्यायोनिसम्बन्धेभ्यः ।
    """
    pass


@registry.register("6.3.24", text="विभाषा स्वसृपत्योः ।")
def rule_6_3_24(ctx=None):
    """
    6.3.24: विभाषा स्वसृपत्योः ।
    """
    pass


@registry.register("6.3.25", text="आनङ् ऋतो द्वंद्वे ।")
def rule_6_3_25(ctx=None):
    """
    6.3.25: आनङ् ऋतो द्वंद्वे ।
    """
    pass


@registry.register("6.3.26", text="देवताद्वंद्वे च ।")
def rule_6_3_26(ctx=None):
    """
    6.3.26: देवताद्वंद्वे च ।
    """
    pass


@registry.register("6.3.27", text="ईदग्नेः सोमवरुणयोः ।")
def rule_6_3_27(ctx=None):
    """
    6.3.27: ईदग्नेः सोमवरुणयोः ।
    """
    pass


@registry.register("6.3.28", text="इद्धृद्धौ ।")
def rule_6_3_28(ctx=None):
    """
    6.3.28: इद्धृद्धौ ।
    """
    pass


@registry.register("6.3.29", text="दिवो द्यावा ।")
def rule_6_3_29(ctx=None):
    """
    6.3.29: दिवो द्यावा ।
    """
    pass


@registry.register("6.3.30", text="दिवसश्च पृथिव्याम् ।")
def rule_6_3_30(ctx=None):
    """
    6.3.30: दिवसश्च पृथिव्याम् ।
    """
    pass


@registry.register("6.3.31", text="उषासोषसः ।")
def rule_6_3_31(ctx=None):
    """
    6.3.31: उषासोषसः ।
    """
    pass


@registry.register("6.3.32", text="मातरपितरावुदीचाम् ।")
def rule_6_3_32(ctx=None):
    """
    6.3.32: मातरपितरावुदीचाम् ।
    """
    pass


@registry.register("6.3.33", text="पितरामातरा च च्छन्दसि ।")
def rule_6_3_33(ctx=None):
    """
    6.3.33: पितरामातरा च च्छन्दसि ।
    """
    pass


@registry.register("6.3.34", text="स्त्रियाः पुंवद्भाषितपुंस्कादनूङ् समानाधिकरणे स्त्रियामपूरणीप्रियाऽऽदिषु ।")
def rule_6_3_34(ctx=None):
    """
    6.3.34: स्त्रियाः पुंवद्भाषितपुंस्कादनूङ् समानाधिकरणे स्त्रियामपूरणीप्रियाऽऽदिषु ।
    """
    pass


@registry.register("6.3.35", text="तसिलादिषु आकृत्वसुचः ।")
def rule_6_3_35(ctx=None):
    """
    6.3.35: तसिलादिषु आकृत्वसुचः ।
    """
    pass


@registry.register("6.3.36", text="क्यङ्गानिनोश्च ।")
def rule_6_3_36(ctx=None):
    """
    6.3.36: क्यङ्गानिनोश्च ।
    """
    pass


@registry.register("6.3.37", text="न कोपधायाः ।")
def rule_6_3_37(ctx=None):
    """
    6.3.37: न कोपधायाः ।
    """
    pass


@registry.register("6.3.38", text="संज्ञापूरण्योश्च ।")
def rule_6_3_38(ctx=None):
    """
    6.3.38: संज्ञापूरण्योश्च ।
    """
    pass


@registry.register("6.3.39", text="वृद्धिनिमित्तस्य च तद्धितस्यारक्तविकारे ।")
def rule_6_3_39(ctx=None):
    """
    6.3.39: वृद्धिनिमित्तस्य च तद्धितस्यारक्तविकारे ।
    """
    pass


@registry.register("6.3.40", text="स्वाङ्गाच्चेतोऽमानिनि ।")
def rule_6_3_40(ctx=None):
    """
    6.3.40: स्वाङ्गाच्चेतोऽमानिनि ।
    """
    pass


@registry.register("6.3.41", text="जातेश्च ।")
def rule_6_3_41(ctx=None):
    """
    6.3.41: जातेश्च ।
    """
    pass


@registry.register("6.3.42", text="पुंवत् कर्मधारयजातीयदेशीयेषु ।")
def rule_6_3_42(ctx=None):
    """
    6.3.42: पुंवत् कर्मधारयजातीयदेशीयेषु ।
    """
    pass


@registry.register("6.3.43", text="घरूपकल्पचेलड्ङ्घवगोत्रमतहतेषु योऽनेकाचो ह्रस्वः ।")
def rule_6_3_43(ctx=None):
    """
    6.3.43: घरूपकल्पचेलड्ङ्घवगोत्रमतहतेषु योऽनेकाचो ह्रस्वः ।
    """
    pass


@registry.register("6.3.44", text="नद्याः शेषस्यान्यतरस्याम् ।")
def rule_6_3_44(ctx=None):
    """
    6.3.44: नद्याः शेषस्यान्यतरस्याम् ।
    """
    pass


@registry.register("6.3.45", text="उगितश्च ।")
def rule_6_3_45(ctx=None):
    """
    6.3.45: उगितश्च ।
    """
    pass


@registry.register("6.3.46", text="आन्महतः समानाधिकरणजातीययोः ।")
def rule_6_3_46(ctx=None):
    """
    6.3.46: आन्महतः समानाधिकरणजातीययोः ।
    """
    pass


@registry.register("6.3.47", text="द्व्यष्टनः संख्यायामबहुव्रीह्यशीत्योः ।")
def rule_6_3_47(ctx=None):
    """
    6.3.47: द्व्यष्टनः संख्यायामबहुव्रीह्यशीत्योः ।
    """
    pass


@registry.register("6.3.48", text="त्रेस्त्रयः ।")
def rule_6_3_48(ctx=None):
    """
    6.3.48: त्रेस्त्रयः ।
    """
    pass


@registry.register("6.3.49", text="विभाषा चत्वारिंशत्प्रभृतौ सर्वेषाम् ।")
def rule_6_3_49(ctx=None):
    """
    6.3.49: विभाषा चत्वारिंशत्प्रभृतौ सर्वेषाम् ।
    """
    pass


@registry.register("6.3.50", text="हृदयस्य हृल्लेखयदण्लासेषु ।")
def rule_6_3_50(ctx=None):
    """
    6.3.50: हृदयस्य हृल्लेखयदण्लासेषु ।
    """
    pass


@registry.register("6.3.51", text="वा शोकष्यत्रोगेषु ।")
def rule_6_3_51(ctx=None):
    """
    6.3.51: वा शोकष्यत्रोगेषु ।
    """
    pass


@registry.register("6.3.52", text="पादस्य पदाज्यातिगोपहतेषु ।")
def rule_6_3_52(ctx=None):
    """
    6.3.52: पादस्य पदाज्यातिगोपहतेषु ।
    """
    pass


@registry.register("6.3.53", text="पद् यत्यतदर्थे ।")
def rule_6_3_53(ctx=None):
    """
    6.3.53: पद् यत्यतदर्थे ।
    """
    pass


@registry.register("6.3.54", text="हिमकाषिहतिषु च ।")
def rule_6_3_54(ctx=None):
    """
    6.3.54: हिमकाषिहतिषु च ।
    """
    pass


@registry.register("6.3.55", text="ऋचः शे ।")
def rule_6_3_55(ctx=None):
    """
    6.3.55: ऋचः शे ।
    """
    pass


@registry.register("6.3.56", text="वा घोषमिश्रशब्देषु ।")
def rule_6_3_56(ctx=None):
    """
    6.3.56: वा घोषमिश्रशब्देषु ।
    """
    pass


@registry.register("6.3.57", text="उदकस्योदः संज्ञायाम् ।")
def rule_6_3_57(ctx=None):
    """
    6.3.57: उदकस्योदः संज्ञायाम् ।
    """
    pass


@registry.register("6.3.58", text="पेषंवासवाहनधिषु च ।")
def rule_6_3_58(ctx=None):
    """
    6.3.58: पेषंवासवाहनधिषु च ।
    """
    pass


@registry.register("6.3.59", text="एकहलादौ पूरयितव्येऽन्यतरस्याम् ।")
def rule_6_3_59(ctx=None):
    """
    6.3.59: एकहलादौ पूरयितव्येऽन्यतरस्याम् ।
    """
    pass


@registry.register("6.3.60", text="मन्थौदनसक्तुबिन्दुवज्रभारहारवीवधगाहेषु च ।")
def rule_6_3_60(ctx=None):
    """
    6.3.60: मन्थौदनसक्तुबिन्दुवज्रभारहारवीवधगाहेषु च ।
    """
    pass


@registry.register("6.3.61", text="इको ह्रस्वोऽड्यो गालवस्य ।")
def rule_6_3_61(ctx=None):
    """
    6.3.61: इको ह्रस्वोऽड्यो गालवस्य ।
    """
    pass


@registry.register("6.3.62", text="एक तद्धिते च ।")
def rule_6_3_62(ctx=None):
    """
    6.3.62: एक तद्धिते च ।
    """
    pass


@registry.register("6.3.63", text="ड्यापोः संज्ञाछन्दसोर्बहुलम् ।")
def rule_6_3_63(ctx=None):
    """
    6.3.63: ड्यापोः संज्ञाछन्दसोर्बहुलम् ।
    """
    pass


@registry.register("6.3.64", text="त्वे च ।")
def rule_6_3_64(ctx=None):
    """
    6.3.64: त्वे च ।
    """
    pass


@registry.register("6.3.65", text="इष्टकेषीकामालानां चिततूलभारिषु ।")
def rule_6_3_65(ctx=None):
    """
    6.3.65: इष्टकेषीकामालानां चिततूलभारिषु ।
    """
    pass


@registry.register("6.3.66", text="खित्यनव्ययस्य ।")
def rule_6_3_66(ctx=None):
    """
    6.3.66: खित्यनव्ययस्य ।
    """
    pass


@registry.register("6.3.67", text="अरुर्द्विषदजन्तस्य मुम् ।")
def rule_6_3_67(ctx=None):
    """
    6.3.67: अरुर्द्विषदजन्तस्य मुम् ।
    """
    pass


@registry.register("6.3.68", text="इच एकाचोऽम्प्रत्ययवच्च ।")
def rule_6_3_68(ctx=None):
    """
    6.3.68: इच एकाचोऽम्प्रत्ययवच्च ।
    """
    pass


@registry.register("6.3.69", text="वाचंयमपुरंदरौ च ।")
def rule_6_3_69(ctx=None):
    """
    6.3.69: वाचंयमपुरंदरौ च ।
    """
    pass


@registry.register("6.3.70", text="कारे सत्यागदस्य ।")
def rule_6_3_70(ctx=None):
    """
    6.3.70: कारे सत्यागदस्य ।
    """
    pass


@registry.register("6.3.71", text="श्येनतिलस्य पाते जे ।")
def rule_6_3_71(ctx=None):
    """
    6.3.71: श्येनतिलस्य पाते जे ।
    """
    pass


@registry.register("6.3.72", text="रात्रेः कृति विभाषा ।")
def rule_6_3_72(ctx=None):
    """
    6.3.72: रात्रेः कृति विभाषा ।
    """
    pass


@registry.register("6.3.73", text="नलोपः नञः ।")
def rule_6_3_73(ctx=None):
    """
    6.3.73: नलोपः नञः ।
    """
    pass


@registry.register("6.3.74", text="तस्मान्नुडचि ।")
def rule_6_3_74(ctx=None):
    """
    6.3.74: तस्मान्नुडचि ।
    """
    pass


@registry.register("6.3.75", text="नभ्राप्नपान्नवेदानासत्यानमुचिनकुलनखनपुंसकनक्षत्रनक्रनाकेषु प्रकृत्या ।")
def rule_6_3_75(ctx=None):
    """
    6.3.75: नभ्राप्नपान्नवेदानासत्यानमुचिनकुलनखनपुंसकनक्षत्रनक्रनाकेषु प्रकृत्या ।
    """
    pass


@registry.register("6.3.76", text="एकादिश्चैकस्य चादुक् ।")
def rule_6_3_76(ctx=None):
    """
    6.3.76: एकादिश्चैकस्य चादुक् ।
    """
    pass


@registry.register("6.3.77", text="नगोऽप्राणिष्वन्यतरस्याम् ।")
def rule_6_3_77(ctx=None):
    """
    6.3.77: नगोऽप्राणिष्वन्यतरस्याम् ।
    """
    pass


@registry.register("6.3.78", text="सहस्य सः संज्ञायाम् ।")
def rule_6_3_78(ctx=None):
    """
    6.3.78: सहस्य सः संज्ञायाम् ।
    """
    pass


@registry.register("6.3.79", text="ग्रन्थान्ताधिके च ।")
def rule_6_3_79(ctx=None):
    """
    6.3.79: ग्रन्थान्ताधिके च ।
    """
    pass


@registry.register("6.3.80", text="द्वितीये चानुपाख्ये ।")
def rule_6_3_80(ctx=None):
    """
    6.3.80: द्वितीये चानुपाख्ये ।
    """
    pass


@registry.register("6.3.81", text="अव्ययीभावे चाकाले ।")
def rule_6_3_81(ctx=None):
    """
    6.3.81: अव्ययीभावे चाकाले ।
    """
    pass


@registry.register("6.3.82", text="वोपसर्जनस्य ।")
def rule_6_3_82(ctx=None):
    """
    6.3.82: वोपसर्जनस्य ।
    """
    pass


@registry.register("6.3.83", text="प्रकृत्याऽऽशिष्यगोवत्सहलेषु ।")
def rule_6_3_83(ctx=None):
    """
    6.3.83: प्रकृत्याऽऽशिष्यगोवत्सहलेषु ।
    """
    pass


@registry.register("6.3.84", text="समानस्य छन्दस्यमूर्धप्रभृत्युदर्केषु ।")
def rule_6_3_84(ctx=None):
    """
    6.3.84: समानस्य छन्दस्यमूर्धप्रभृत्युदर्केषु ।
    """
    pass


@registry.register("6.3.85", text="ज्योतिर्जनपदरात्रिनाभिनामगोत्ररूपस्थानवर्णवयोवचनबन्धुषु ।")
def rule_6_3_85(ctx=None):
    """
    6.3.85: ज्योतिर्जनपदरात्रिनाभिनामगोत्ररूपस्थानवर्णवयोवचनबन्धुषु ।
    """
    pass


@registry.register("6.3.86", text="चरणे ब्रह्मचारिणि ।")
def rule_6_3_86(ctx=None):
    """
    6.3.86: चरणे ब्रह्मचारिणि ।
    """
    pass


@registry.register("6.3.87", text="तीर्थे ये ।")
def rule_6_3_87(ctx=None):
    """
    6.3.87: तीर्थे ये ।
    """
    pass


@registry.register("6.3.88", text="विभाषोदरे ।")
def rule_6_3_88(ctx=None):
    """
    6.3.88: विभाषोदरे ।
    """
    pass


@registry.register("6.3.89", text="दृग्दृशवतुषु ।")
def rule_6_3_89(ctx=None):
    """
    6.3.89: दृग्दृशवतुषु ।
    """
    pass


@registry.register("6.3.90", text="इदङ्किमोरीश्की ।")
def rule_6_3_90(ctx=None):
    """
    6.3.90: इदङ्किमोरीश्की ।
    """
    pass


@registry.register("6.3.91", text="आ सर्वनाम्नः ।")
def rule_6_3_91(ctx=None):
    """
    6.3.91: आ सर्वनाम्नः ।
    """
    pass


@registry.register("6.3.92", text="विष्वग्देवयोश्च टेरद्र्यञ्श्चतौ वप्रत्यये ।")
def rule_6_3_92(ctx=None):
    """
    6.3.92: विष्वग्देवयोश्च टेरद्र्यञ्श्चतौ वप्रत्यये ।
    """
    pass


@registry.register("6.3.93", text="समः समि ।")
def rule_6_3_93(ctx=None):
    """
    6.3.93: समः समि ।
    """
    pass


@registry.register("6.3.94", text="तिरसस्तिर्यलोपे ।")
def rule_6_3_94(ctx=None):
    """
    6.3.94: तिरसस्तिर्यलोपे ।
    """
    pass


@registry.register("6.3.95", text="सहस्य सध्रिः ।")
def rule_6_3_95(ctx=None):
    """
    6.3.95: सहस्य सध्रिः ।
    """
    pass


@registry.register("6.3.96", text="सध मादस्थयोश्छन्दसि ।")
def rule_6_3_96(ctx=None):
    """
    6.3.96: सध मादस्थयोश्छन्दसि ।
    """
    pass


@registry.register("6.3.97", text="व्यन्तरुपसर्गेभ्योऽप ईत् ।")
def rule_6_3_97(ctx=None):
    """
    6.3.97: व्यन्तरुपसर्गेभ्योऽप ईत् ।
    """
    pass


@registry.register("6.3.98", text="ऊदनोर्देशे ।")
def rule_6_3_98(ctx=None):
    """
    6.3.98: ऊदनोर्देशे ।
    """
    pass


@registry.register("6.3.99", text="अषष्ठ्ठयतृतीयास्थस्यान्यस्य दुगाशिराशाऽऽस्था ऽऽस्थितोत्सुकोतिकारकरागच्छेषु ।")
def rule_6_3_99(ctx=None):
    """
    6.3.99: अषष्ठ्ठयतृतीयास्थस्यान्यस्य दुगाशिराशाऽऽस्था ऽऽस्थितोत्सुकोतिकारकरागच्छेषु ।
    """
    pass


@registry.register("6.3.100", text="अर्थे विभाषा ।")
def rule_6_3_100(ctx=None):
    """
    6.3.100: अर्थे विभाषा ।
    """
    pass


@registry.register("6.3.101", text="कोः कत् तत्पुरुषेऽचि ।")
def rule_6_3_101(ctx=None):
    """
    6.3.101: कोः कत् तत्पुरुषेऽचि ।
    """
    pass


@registry.register("6.3.102", text="रथवदयोश्च ।")
def rule_6_3_102(ctx=None):
    """
    6.3.102: रथवदयोश्च ।
    """
    pass


@registry.register("6.3.103", text="तृणे च जातौ ।")
def rule_6_3_103(ctx=None):
    """
    6.3.103: तृणे च जातौ ।
    """
    pass


@registry.register("6.3.104", text="का पथ्यक्षयोः ।")
def rule_6_3_104(ctx=None):
    """
    6.3.104: का पथ्यक्षयोः ।
    """
    pass


@registry.register("6.3.105", text="ईषदर्थे ।")
def rule_6_3_105(ctx=None):
    """
    6.3.105: ईषदर्थे ।
    """
    pass


@registry.register("6.3.106", text="विभाषा पुरुषे ।")
def rule_6_3_106(ctx=None):
    """
    6.3.106: विभाषा पुरुषे ।
    """
    pass


@registry.register("6.3.107", text="कवं चोष्णे ।")
def rule_6_3_107(ctx=None):
    """
    6.3.107: कवं चोष्णे ।
    """
    pass


@registry.register("6.3.108", text="पथि च च्छन्दसि ।")
def rule_6_3_108(ctx=None):
    """
    6.3.108: पथि च च्छन्दसि ।
    """
    pass


@registry.register("6.3.109", text="पृषोदरादीनि यथोपदिष्टम् ।")
def rule_6_3_109(ctx=None):
    """
    6.3.109: पृषोदरादीनि यथोपदिष्टम् ।
    """
    pass


@registry.register("6.3.110", text="संख्याविसायपूर्वस्याह्रस्याहन्नन्यतरस्यां ङौ ।")
def rule_6_3_110(ctx=None):
    """
    6.3.110: संख्याविसायपूर्वस्याह्रस्याहन्नन्यतरस्यां ङौ ।
    """
    pass


@registry.register("6.3.111", text="ठूलोपे पूर्वस्य दीर्घोऽणः ।")
def rule_6_3_111(ctx=None):
    """
    6.3.111: ठूलोपे पूर्वस्य दीर्घोऽणः ।
    """
    pass


@registry.register("6.3.112", text="सहिवहोरोदवर्णस्य ।")
def rule_6_3_112(ctx=None):
    """
    6.3.112: सहिवहोरोदवर्णस्य ।
    """
    pass


@registry.register("6.3.113", text="साढ्यै साट्वा साढेति निगमे ।")
def rule_6_3_113(ctx=None):
    """
    6.3.113: साढ्यै साट्वा साढेति निगमे ।
    """
    pass


@registry.register("6.3.114", text="संहितायाम् ।")
def rule_6_3_114(ctx=None):
    """
    6.3.114: संहितायाम् ।
    """
    pass


@registry.register("6.3.115", text="कर्णे लक्षणस्याविष्टाष्टपञ्चमणिभिन्नच्छिन्नछिद्रस्रुवस्वस्तिकस्य ।")
def rule_6_3_115(ctx=None):
    """
    6.3.115: कर्णे लक्षणस्याविष्टाष्टपञ्चमणिभिन्नच्छिन्नछिद्रस्रुवस्वस्तिकस्य ।
    """
    pass


@registry.register("6.3.116", text="नहिवृतिवृषिव्यधिरुचिसहितनिषु ।")
def rule_6_3_116(ctx=None):
    """
    6.3.116: नहिवृतिवृषिव्यधिरुचिसहितनिषु ।
    """
    pass


@registry.register("6.3.117", text="वनगिर्योः संज्ञायां कोटरकिंशुलकादीनाम् ।")
def rule_6_3_117(ctx=None):
    """
    6.3.117: वनगिर्योः संज्ञायां कोटरकिंशुलकादीनाम् ।
    """
    pass


@registry.register("6.3.118", text="वले ।")
def rule_6_3_118(ctx=None):
    """
    6.3.118: वले ।
    """
    pass


@registry.register("6.3.119", text="मतौ बह्वचोऽनजिरादीनाम् ।")
def rule_6_3_119(ctx=None):
    """
    6.3.119: मतौ बह्वचोऽनजिरादीनाम् ।
    """
    pass


@registry.register("6.3.120", text="शरादीनां च ।")
def rule_6_3_120(ctx=None):
    """
    6.3.120: शरादीनां च ।
    """
    pass


@registry.register("6.3.121", text="इकः वहे अपीलोः ।")
def rule_6_3_121(ctx=None):
    """
    6.3.121: इकः वहे अपीलोः ।
    """
    pass


@registry.register("6.3.122", text="उपसर्गस्य घञ्यमनुष्ये बहुलम् ।")
def rule_6_3_122(ctx=None):
    """
    6.3.122: उपसर्गस्य घञ्यमनुष्ये बहुलम् ।
    """
    pass


@registry.register("6.3.123", text="इकः काशे ।")
def rule_6_3_123(ctx=None):
    """
    6.3.123: इकः काशे ।
    """
    pass


@registry.register("6.3.124", text="दस्ति ।")
def rule_6_3_124(ctx=None):
    """
    6.3.124: दस्ति ।
    """
    pass


@registry.register("6.3.125", text="अष्टनः संज्ञायाम् ।")
def rule_6_3_125(ctx=None):
    """
    6.3.125: अष्टनः संज्ञायाम् ।
    """
    pass


@registry.register("6.3.126", text="छन्दसि च ।")
def rule_6_3_126(ctx=None):
    """
    6.3.126: छन्दसि च ।
    """
    pass


@registry.register("6.3.127", text="चितेः कपि ।")
def rule_6_3_127(ctx=None):
    """
    6.3.127: चितेः कपि ।
    """
    pass


@registry.register("6.3.128", text="विश्वस्य वसुराटोः ।")
def rule_6_3_128(ctx=None):
    """
    6.3.128: विश्वस्य वसुराटोः ।
    """
    pass


@registry.register("6.3.129", text="नरे संज्ञायाम् ।")
def rule_6_3_129(ctx=None):
    """
    6.3.129: नरे संज्ञायाम् ।
    """
    pass


@registry.register("6.3.130", text="मित्रे चर्षो ।")
def rule_6_3_130(ctx=None):
    """
    6.3.130: मित्रे चर्षो ।
    """
    pass


@registry.register("6.3.131", text="मन्त्रे सोमाश्वेन्द्रियविश्वदेव्यस्य मतौ ।")
def rule_6_3_131(ctx=None):
    """
    6.3.131: मन्त्रे सोमाश्वेन्द्रियविश्वदेव्यस्य मतौ ।
    """
    pass


@registry.register("6.3.132", text="ओषधेश्च विभक्तावप्रथमायाम् ।")
def rule_6_3_132(ctx=None):
    """
    6.3.132: ओषधेश्च विभक्तावप्रथमायाम् ।
    """
    pass


@registry.register("6.3.133", text="ऋचि तुनुघमक्षुतङ्कुत्रोरुष्याणाम् ।")
def rule_6_3_133(ctx=None):
    """
    6.3.133: ऋचि तुनुघमक्षुतङ्कुत्रोरुष्याणाम् ।
    """
    pass


@registry.register("6.3.134", text="इकः सुञि ।")
def rule_6_3_134(ctx=None):
    """
    6.3.134: इकः सुञि ।
    """
    pass


@registry.register("6.3.135", text="व्यचोऽतस्तिङः ।")
def rule_6_3_135(ctx=None):
    """
    6.3.135: व्यचोऽतस्तिङः ।
    """
    pass


@registry.register("6.3.136", text="निपातस्य च ।")
def rule_6_3_136(ctx=None):
    """
    6.3.136: निपातस्य च ।
    """
    pass


@registry.register("6.3.137", text="अन्येषामपि दृश्यते ।")
def rule_6_3_137(ctx=None):
    """
    6.3.137: अन्येषामपि दृश्यते ।
    """
    pass


@registry.register("6.3.138", text="चौ ।")
def rule_6_3_138(ctx=None):
    """
    6.3.138: चौ ।
    """
    pass


@registry.register("6.3.139", text="सम्प्रसारणस्य ।")
def rule_6_3_139(ctx=None):
    """
    6.3.139: सम्प्रसारणस्य ।
    """
    pass


@registry.register("6.4.1", text="अङ्गस्य ।")
def rule_6_4_1(ctx=None):
    """
    6.4.1: अङ्गस्य ।
    """
    pass


@registry.register("6.4.2", text="हलः ।")
def rule_6_4_2(ctx=None):
    """
    6.4.2: हलः ।
    """
    pass


@registry.register("6.4.3", text="नामि ।")
def rule_6_4_3(ctx=None):
    """
    6.4.3: नामि ।
    """
    pass


@registry.register("6.4.4", text="न तिसृचतसृ ।")
def rule_6_4_4(ctx=None):
    """
    6.4.4: न तिसृचतसृ ।
    """
    pass


@registry.register("6.4.5", text="छन्दस्युभयथा ।")
def rule_6_4_5(ctx=None):
    """
    6.4.5: छन्दस्युभयथा ।
    """
    pass


@registry.register("6.4.6", text="नृ च ।")
def rule_6_4_6(ctx=None):
    """
    6.4.6: नृ च ।
    """
    pass


@registry.register("6.4.7", text="नोपधायाः ।")
def rule_6_4_7(ctx=None):
    """
    6.4.7: नोपधायाः ।
    """
    pass


@registry.register("6.4.8", text="सर्वनामस्थाने चासम्बुद्धौ ।")
def rule_6_4_8(ctx=None):
    """
    6.4.8: सर्वनामस्थाने चासम्बुद्धौ ।
    """
    pass


@registry.register("6.4.9", text="वा षपूर्वस्य निगमे ।")
def rule_6_4_9(ctx=None):
    """
    6.4.9: वा षपूर्वस्य निगमे ।
    """
    pass


@registry.register("6.4.10", text="सान्तमहतः संयोगस्य ।")
def rule_6_4_10(ctx=None):
    """
    6.4.10: सान्तमहतः संयोगस्य ।
    """
    pass


@registry.register("6.4.11", text="अप्तृन्तृच्स्वसृनप्तृनेष्टत्वष्टक्षत्तृहोतृपोतृप्रशास्तृणाम् ।")
def rule_6_4_11(ctx=None):
    """
    6.4.11: अप्तृन्तृच्स्वसृनप्तृनेष्टत्वष्टक्षत्तृहोतृपोतृप्रशास्तृणाम् ।
    """
    pass


@registry.register("6.4.12", text="इन्हन्पूषार्यम्णां शौ ।")
def rule_6_4_12(ctx=None):
    """
    6.4.12: इन्हन्पूषार्यम्णां शौ ।
    """
    pass


@registry.register("6.4.13", text="सौ च ।")
def rule_6_4_13(ctx=None):
    """
    6.4.13: सौ च ।
    """
    pass


@registry.register("6.4.14", text="अत्वसन्तस्य चाधातोः ।")
def rule_6_4_14(ctx=None):
    """
    6.4.14: अत्वसन्तस्य चाधातोः ।
    """
    pass


@registry.register("6.4.15", text="अनुनासिकस्य क्विझलोः क्कृिति ।")
def rule_6_4_15(ctx=None):
    """
    6.4.15: अनुनासिकस्य क्विझलोः क्कृिति ।
    """
    pass


@registry.register("6.4.16", text="अज्झनगमां सनि ।")
def rule_6_4_16(ctx=None):
    """
    6.4.16: अज्झनगमां सनि ।
    """
    pass


@registry.register("6.4.17", text="तनोतेर्विभाषा ।")
def rule_6_4_17(ctx=None):
    """
    6.4.17: तनोतेर्विभाषा ।
    """
    pass


@registry.register("6.4.18", text="क्रमश्च ।")
def rule_6_4_18(ctx=None):
    """
    6.4.18: क्रमश्च ।
    """
    pass


@registry.register("6.4.19", text="शूडनुनासिके च ।")
def rule_6_4_19(ctx=None):
    """
    6.4.19: शूडनुनासिके च ।
    """
    pass


@registry.register("6.4.20", text="ज्वरत्वरश्रिव्यविमवामुपधायाश्च ।")
def rule_6_4_20(ctx=None):
    """
    6.4.20: ज्वरत्वरश्रिव्यविमवामुपधायाश्च ।
    """
    pass


@registry.register("6.4.21", text="राल्लोपः ।")
def rule_6_4_21(ctx=None):
    """
    6.4.21: राल्लोपः ।
    """
    pass


@registry.register("6.4.22", text="असिद्धवदत्राभात् ।")
def rule_6_4_22(ctx=None):
    """
    6.4.22: असिद्धवदत्राभात् ।
    """
    pass


@registry.register("6.4.23", text="श्नान्नलोपः ।")
def rule_6_4_23(ctx=None):
    """
    6.4.23: श्नान्नलोपः ।
    """
    pass


@registry.register("6.4.24", text="अनिदितां हल उपधायाः क्कृिति ।")
def rule_6_4_24(ctx=None):
    """
    6.4.24: अनिदितां हल उपधायाः क्कृिति ।
    """
    pass


@registry.register("6.4.25", text="दन्शसञ्जस्वञ्जां शपि ।")
def rule_6_4_25(ctx=None):
    """
    6.4.25: दन्शसञ्जस्वञ्जां शपि ।
    """
    pass


@registry.register("6.4.26", text="रञ्जश्च ।")
def rule_6_4_26(ctx=None):
    """
    6.4.26: रञ्जश्च ।
    """
    pass


@registry.register("6.4.27", text="घञि च भावकरणयोः ।")
def rule_6_4_27(ctx=None):
    """
    6.4.27: घञि च भावकरणयोः ।
    """
    pass


@registry.register("6.4.28", text="स्यदो जवे ।")
def rule_6_4_28(ctx=None):
    """
    6.4.28: स्यदो जवे ।
    """
    pass


@registry.register("6.4.29", text="अवोदैधौद्मप्रश्रथहिमश्रथाः ।")
def rule_6_4_29(ctx=None):
    """
    6.4.29: अवोदैधौद्मप्रश्रथहिमश्रथाः ।
    """
    pass


@registry.register("6.4.30", text="नाश्चेः पूजायाम् ।")
def rule_6_4_30(ctx=None):
    """
    6.4.30: नाश्चेः पूजायाम् ।
    """
    pass


@registry.register("6.4.31", text="स्कन्दिस्यन्दोः ।")
def rule_6_4_31(ctx=None):
    """
    6.4.31: स्कन्दिस्यन्दोः ।
    """
    pass


@registry.register("6.4.32", text="जान्तनशां विभाषा ।")
def rule_6_4_32(ctx=None):
    """
    6.4.32: जान्तनशां विभाषा ।
    """
    pass


@registry.register("6.4.33", text="भञ्जश्च चिणि ।")
def rule_6_4_33(ctx=None):
    """
    6.4.33: भञ्जश्च चिणि ।
    """
    pass


@registry.register("6.4.34", text="शास इदङ्गलोः ।")
def rule_6_4_34(ctx=None):
    """
    6.4.34: शास इदङ्गलोः ।
    """
    pass


@registry.register("6.4.35", text="शा हौ ।")
def rule_6_4_35(ctx=None):
    """
    6.4.35: शा हौ ।
    """
    pass


@registry.register("6.4.36", text="हन्तेर्जः ।")
def rule_6_4_36(ctx=None):
    """
    6.4.36: हन्तेर्जः ।
    """
    pass


@registry.register("6.4.37", text="अनुदात्तोपदेशवनतितनोत्यादीनामनुनासिकलोपो झलि क्ङिति ।")
def rule_6_4_37(ctx=None):
    """
    6.4.37: अनुदात्तोपदेशवनतितनोत्यादीनामनुनासिकलोपो झलि क्ङिति ।
    """
    pass


@registry.register("6.4.38", text="वा ल्यपि ।")
def rule_6_4_38(ctx=None):
    """
    6.4.38: वा ल्यपि ।
    """
    pass


@registry.register("6.4.39", text="न क्तिचि दीर्घश्च ।")
def rule_6_4_39(ctx=None):
    """
    6.4.39: न क्तिचि दीर्घश्च ।
    """
    pass


@registry.register("6.4.40", text="गमः ।")
def rule_6_4_40(ctx=None):
    """
    6.4.40: गमः ।
    """
    pass


@registry.register("6.4.41", text="विड्वनोरनुनासिकस्यात् ।")
def rule_6_4_41(ctx=None):
    """
    6.4.41: विड्वनोरनुनासिकस्यात् ।
    """
    pass


@registry.register("6.4.42", text="जनसनखनां सञ्झलोः ।")
def rule_6_4_42(ctx=None):
    """
    6.4.42: जनसनखनां सञ्झलोः ।
    """
    pass


@registry.register("6.4.43", text="ये विभाषा ।")
def rule_6_4_43(ctx=None):
    """
    6.4.43: ये विभाषा ।
    """
    pass


@registry.register("6.4.44", text="तनोतेर्यकि ।")
def rule_6_4_44(ctx=None):
    """
    6.4.44: तनोतेर्यकि ।
    """
    pass


@registry.register("6.4.45", text="सनः क्तिचि लोपश्चास्यान्यतरस्याम् ।")
def rule_6_4_45(ctx=None):
    """
    6.4.45: सनः क्तिचि लोपश्चास्यान्यतरस्याम् ।
    """
    pass


@registry.register("6.4.46", text="आर्धधातुके ।")
def rule_6_4_46(ctx=None):
    """
    6.4.46: आर्धधातुके ।
    """
    pass


@registry.register("6.4.47", text="भ्रस्नो रोपधयोः रमन्यतरस्याम् ।")
def rule_6_4_47(ctx=None):
    """
    6.4.47: भ्रस्नो रोपधयोः रमन्यतरस्याम् ।
    """
    pass


@registry.register("6.4.48", text="अतो लोपः ।")
def rule_6_4_48(ctx=None):
    """
    6.4.48: अतो लोपः ।
    """
    pass


@registry.register("6.4.49", text="यस्य हलः ।")
def rule_6_4_49(ctx=None):
    """
    6.4.49: यस्य हलः ।
    """
    pass


@registry.register("6.4.50", text="क्यस्य विभाषा ।")
def rule_6_4_50(ctx=None):
    """
    6.4.50: क्यस्य विभाषा ।
    """
    pass


@registry.register("6.4.51", text="णेरनिटि ।")
def rule_6_4_51(ctx=None):
    """
    6.4.51: णेरनिटि ।
    """
    pass


@registry.register("6.4.52", text="निष्ठायां सेटि ।")
def rule_6_4_52(ctx=None):
    """
    6.4.52: निष्ठायां सेटि ।
    """
    pass


@registry.register("6.4.53", text="जनिता मन्त्रे।")
def rule_6_4_53(ctx=None):
    """
    6.4.53: जनिता मन्त्रे।
    """
    pass


@registry.register("6.4.54", text="शमिता यज्ञे।")
def rule_6_4_54(ctx=None):
    """
    6.4.54: शमिता यज्ञे।
    """
    pass


@registry.register("6.4.55", text="अयामन्ताल्वाय्येत्न्विष्णुषु।")
def rule_6_4_55(ctx=None):
    """
    6.4.55: अयामन्ताल्वाय्येत्न्विष्णुषु।
    """
    pass


@registry.register("6.4.56", text="ल्यपि लघुपूर्वात् ।")
def rule_6_4_56(ctx=None):
    """
    6.4.56: ल्यपि लघुपूर्वात् ।
    """
    pass


@registry.register("6.4.57", text="विभाषाऽऽपः ।")
def rule_6_4_57(ctx=None):
    """
    6.4.57: विभाषाऽऽपः ।
    """
    pass


@registry.register("6.4.58", text="युप्लुवोर्दीर्घश्छन्दसि ।")
def rule_6_4_58(ctx=None):
    """
    6.4.58: युप्लुवोर्दीर्घश्छन्दसि ।
    """
    pass


@registry.register("6.4.59", text="क्षियः ।")
def rule_6_4_59(ctx=None):
    """
    6.4.59: क्षियः ।
    """
    pass


@registry.register("6.4.60", text="निष्ठायां अण्यदर्थे ।")
def rule_6_4_60(ctx=None):
    """
    6.4.60: निष्ठायां अण्यदर्थे ।
    """
    pass


@registry.register("6.4.61", text="वाऽऽक्रोशदैन्ययोः ।")
def rule_6_4_61(ctx=None):
    """
    6.4.61: वाऽऽक्रोशदैन्ययोः ।
    """
    pass


@registry.register("6.4.62", text="स्यसिच्सीयुट्तासिषुभावकर्मणोर् उपदेशेऽज्झनग्रहदृशां वा चिण्वदिट् च ।")
def rule_6_4_62(ctx=None):
    """
    6.4.62: स्यसिच्सीयुट्तासिषुभावकर्मणोर् उपदेशेऽज्झनग्रहदृशां वा चिण्वदिट् च ।
    """
    pass


@registry.register("6.4.63", text="दीङोयुडचि क्ङिति ।")
def rule_6_4_63(ctx=None):
    """
    6.4.63: दीङोयुडचि क्ङिति ।
    """
    pass


@registry.register("6.4.64", text="आतोलोप इटि च ।")
def rule_6_4_64(ctx=None):
    """
    6.4.64: आतोलोप इटि च ।
    """
    pass


@registry.register("6.4.65", text="ईद्यति ।")
def rule_6_4_65(ctx=None):
    """
    6.4.65: ईद्यति ।
    """
    pass


@registry.register("6.4.66", text="घुमास्थागापाजहातिसां हलि ।")
def rule_6_4_66(ctx=None):
    """
    6.4.66: घुमास्थागापाजहातिसां हलि ।
    """
    pass


@registry.register("6.4.67", text="एर्लिङि ।")
def rule_6_4_67(ctx=None):
    """
    6.4.67: एर्लिङि ।
    """
    pass


@registry.register("6.4.68", text="वाऽन्यस्य संयोगादेः ।")
def rule_6_4_68(ctx=None):
    """
    6.4.68: वाऽन्यस्य संयोगादेः ।
    """
    pass


@registry.register("6.4.69", text="न ल्यपि ।")
def rule_6_4_69(ctx=None):
    """
    6.4.69: न ल्यपि ।
    """
    pass


@registry.register("6.4.70", text="मयतेरिदन्यतरस्याम् ।")
def rule_6_4_70(ctx=None):
    """
    6.4.70: मयतेरिदन्यतरस्याम् ।
    """
    pass


@registry.register("6.4.71", text="लुङ्लङ्लृङ्क्ष्वडुदात्तः ।")
def rule_6_4_71(ctx=None):
    """
    6.4.71: लुङ्लङ्लृङ्क्ष्वडुदात्तः ।
    """
    pass


@registry.register("6.4.72", text="आडजादीनाम् ।")
def rule_6_4_72(ctx=None):
    """
    6.4.72: आडजादीनाम् ।
    """
    pass


@registry.register("6.4.73", text="छन्दस्यपि दृश्यते।")
def rule_6_4_73(ctx=None):
    """
    6.4.73: छन्दस्यपि दृश्यते।
    """
    pass


@registry.register("6.4.74", text="न माङ्योगे।")
def rule_6_4_74(ctx=None):
    """
    6.4.74: न माङ्योगे।
    """
    pass


@registry.register("6.4.75", text="बहुलं छन्दस्यमाङ्योगेऽपि ।")
def rule_6_4_75(ctx=None):
    """
    6.4.75: बहुलं छन्दस्यमाङ्योगेऽपि ।
    """
    pass


@registry.register("6.4.76", text="इरयोरे।")
def rule_6_4_76(ctx=None):
    """
    6.4.76: इरयोरे।
    """
    pass


@registry.register("6.4.77", text="अचि श्नुधातुभ्रुवां य्वोरियङुवङौ।")
def rule_6_4_77(ctx=None):
    """
    6.4.77: अचि श्नुधातुभ्रुवां य्वोरियङुवङौ।
    """
    pass


@registry.register("6.4.78", text="अभ्यासस्यासवर्णे ।")
def rule_6_4_78(ctx=None):
    """
    6.4.78: अभ्यासस्यासवर्णे ।
    """
    pass


@registry.register("6.4.79", text="स्त्रियाः ।")
def rule_6_4_79(ctx=None):
    """
    6.4.79: स्त्रियाः ।
    """
    pass


@registry.register("6.4.80", text="वाऽम्शसोः ।")
def rule_6_4_80(ctx=None):
    """
    6.4.80: वाऽम्शसोः ।
    """
    pass


@registry.register("6.4.81", text="इणोयण् ।")
def rule_6_4_81(ctx=None):
    """
    6.4.81: इणोयण् ।
    """
    pass


@registry.register("6.4.82", text="एरनेकाचोऽसंयोगपूर्वस्य ।")
def rule_6_4_82(ctx=None):
    """
    6.4.82: एरनेकाचोऽसंयोगपूर्वस्य ।
    """
    pass


@registry.register("6.4.83", text="ओः सुपि ।")
def rule_6_4_83(ctx=None):
    """
    6.4.83: ओः सुपि ।
    """
    pass


@registry.register("6.4.84", text="वर्षाभ्वश्च ।")
def rule_6_4_84(ctx=None):
    """
    6.4.84: वर्षाभ्वश्च ।
    """
    pass


@registry.register("6.4.85", text="न भूसुधियोः ।")
def rule_6_4_85(ctx=None):
    """
    6.4.85: न भूसुधियोः ।
    """
    pass


@registry.register("6.4.86", text="छन्दस्युभयथा ।")
def rule_6_4_86(ctx=None):
    """
    6.4.86: छन्दस्युभयथा ।
    """
    pass


@registry.register("6.4.87", text="हुश्नुवोः सार्वधातुके ।")
def rule_6_4_87(ctx=None):
    """
    6.4.87: हुश्नुवोः सार्वधातुके ।
    """
    pass


@registry.register("6.4.88", text="भुवोवुग्लुङ्लिटोः ।")
def rule_6_4_88(ctx=None):
    """
    6.4.88: भुवोवुग्लुङ्लिटोः ।
    """
    pass


@registry.register("6.4.89", text="ऊदुपधाया गोहः ।")
def rule_6_4_89(ctx=None):
    """
    6.4.89: ऊदुपधाया गोहः ।
    """
    pass


@registry.register("6.4.90", text="दोषोणौ।")
def rule_6_4_90(ctx=None):
    """
    6.4.90: दोषोणौ।
    """
    pass


@registry.register("6.4.91", text="वा चित्तविरागे।")
def rule_6_4_91(ctx=None):
    """
    6.4.91: वा चित्तविरागे।
    """
    pass


@registry.register("6.4.92", text="मितां ह्रस्वः ।")
def rule_6_4_92(ctx=None):
    """
    6.4.92: मितां ह्रस्वः ।
    """
    pass


@registry.register("6.4.93", text="चिण्णमुलोर्दीर्घोऽन्यतरस्याम् ।")
def rule_6_4_93(ctx=None):
    """
    6.4.93: चिण्णमुलोर्दीर्घोऽन्यतरस्याम् ।
    """
    pass


@registry.register("6.4.94", text="खचि ह्रस्वः ।")
def rule_6_4_94(ctx=None):
    """
    6.4.94: खचि ह्रस्वः ।
    """
    pass


@registry.register("6.4.95", text="ह्लादोनिष्ठायाम् ।")
def rule_6_4_95(ctx=None):
    """
    6.4.95: ह्लादोनिष्ठायाम् ।
    """
    pass


@registry.register("6.4.96", text="छादेर्घेऽद्व्युपसर्गस्य ।")
def rule_6_4_96(ctx=None):
    """
    6.4.96: छादेर्घेऽद्व्युपसर्गस्य ।
    """
    pass


@registry.register("6.4.97", text="इस्मन्त्रन्क्विषुच ।")
def rule_6_4_97(ctx=None):
    """
    6.4.97: इस्मन्त्रन्क्विषुच ।
    """
    pass


@registry.register("6.4.98", text="गमहनजनखनघसां लोपः क्ङित्यनङि ।")
def rule_6_4_98(ctx=None):
    """
    6.4.98: गमहनजनखनघसां लोपः क्ङित्यनङि ।
    """
    pass


@registry.register("6.4.99", text="तनिपत्योश्छन्दसि ।")
def rule_6_4_99(ctx=None):
    """
    6.4.99: तनिपत्योश्छन्दसि ।
    """
    pass


@registry.register("6.4.100", text="घसिभसोर्हलि च ।")
def rule_6_4_100(ctx=None):
    """
    6.4.100: घसिभसोर्हलि च ।
    """
    pass


@registry.register("6.4.101", text="हुझल्भ्योहेर्धिः ।")
def rule_6_4_101(ctx=None):
    """
    6.4.101: हुझल्भ्योहेर्धिः ।
    """
    pass


@registry.register("6.4.102", text="श्रुश‍ृणुपॄकृवृभ्यश्छन्दसि ।")
def rule_6_4_102(ctx=None):
    """
    6.4.102: श्रुश‍ृणुपॄकृवृभ्यश्छन्दसि ।
    """
    pass


@registry.register("6.4.103", text="अङितश्च ।")
def rule_6_4_103(ctx=None):
    """
    6.4.103: अङितश्च ।
    """
    pass


@registry.register("6.4.104", text="चिणोलुक् ।")
def rule_6_4_104(ctx=None):
    """
    6.4.104: चिणोलुक् ।
    """
    pass


@registry.register("6.4.105", text="अतोहेः ।")
def rule_6_4_105(ctx=None):
    """
    6.4.105: अतोहेः ।
    """
    pass


@registry.register("6.4.106", text="उतश्च प्रत्ययादसंयोगपूर्वात् ।")
def rule_6_4_106(ctx=None):
    """
    6.4.106: उतश्च प्रत्ययादसंयोगपूर्वात् ।
    """
    pass


@registry.register("6.4.107", text="लोपश्चास्यान्यतरस्यां म्वोः ।")
def rule_6_4_107(ctx=None):
    """
    6.4.107: लोपश्चास्यान्यतरस्यां म्वोः ।
    """
    pass


@registry.register("6.4.108", text="नित्यं करोतेः ।")
def rule_6_4_108(ctx=None):
    """
    6.4.108: नित्यं करोतेः ।
    """
    pass


@registry.register("6.4.109", text="येच ।")
def rule_6_4_109(ctx=None):
    """
    6.4.109: येच ।
    """
    pass


@registry.register("6.4.110", text="अत उत् सार्वधातुके ।")
def rule_6_4_110(ctx=None):
    """
    6.4.110: अत उत् सार्वधातुके ।
    """
    pass


@registry.register("6.4.111", text="श्नसोरल्लोपः ।")
def rule_6_4_111(ctx=None):
    """
    6.4.111: श्नसोरल्लोपः ।
    """
    pass


@registry.register("6.4.112", text="श्नाऽभ्यस्तयोरातः ।")
def rule_6_4_112(ctx=None):
    """
    6.4.112: श्नाऽभ्यस्तयोरातः ।
    """
    pass


@registry.register("6.4.113", text="ई हल्यघोः ।")
def rule_6_4_113(ctx=None):
    """
    6.4.113: ई हल्यघोः ।
    """
    pass


@registry.register("6.4.114", text="इद्दरिद्रस्य ।")
def rule_6_4_114(ctx=None):
    """
    6.4.114: इद्दरिद्रस्य ।
    """
    pass


@registry.register("6.4.115", text="भियोऽन्यतरस्याम् ।")
def rule_6_4_115(ctx=None):
    """
    6.4.115: भियोऽन्यतरस्याम् ।
    """
    pass


@registry.register("6.4.116", text="जहातेश्च ।")
def rule_6_4_116(ctx=None):
    """
    6.4.116: जहातेश्च ।
    """
    pass


@registry.register("6.4.117", text="आ च हौ।")
def rule_6_4_117(ctx=None):
    """
    6.4.117: आ च हौ।
    """
    pass


@registry.register("6.4.118", text="लोपोयि ।")
def rule_6_4_118(ctx=None):
    """
    6.4.118: लोपोयि ।
    """
    pass


@registry.register("6.4.119", text="घ्वसोरेद्धावभ्यासलोपश्च ।")
def rule_6_4_119(ctx=None):
    """
    6.4.119: घ्वसोरेद्धावभ्यासलोपश्च ।
    """
    pass


@registry.register("6.4.120", text="अत एकहल्मध्येऽनादेशादेर्लिटि ।")
def rule_6_4_120(ctx=None):
    """
    6.4.120: अत एकहल्मध्येऽनादेशादेर्लिटि ।
    """
    pass


@registry.register("6.4.121", text="थलि च सेटि ।")
def rule_6_4_121(ctx=None):
    """
    6.4.121: थलि च सेटि ।
    """
    pass


@registry.register("6.4.122", text="तॄफलभजत्रपश्च ।")
def rule_6_4_122(ctx=None):
    """
    6.4.122: तॄफलभजत्रपश्च ।
    """
    pass


@registry.register("6.4.123", text="राधोहिंसायाम् ।")
def rule_6_4_123(ctx=None):
    """
    6.4.123: राधोहिंसायाम् ।
    """
    pass


@registry.register("6.4.124", text="वा जॄभ्रमुत्रसाम् ।")
def rule_6_4_124(ctx=None):
    """
    6.4.124: वा जॄभ्रमुत्रसाम् ।
    """
    pass


@registry.register("6.4.125", text="फणां च सप्तानाम् ।")
def rule_6_4_125(ctx=None):
    """
    6.4.125: फणां च सप्तानाम् ।
    """
    pass


@registry.register("6.4.126", text="न शसददवादिगुणानाम् ।")
def rule_6_4_126(ctx=None):
    """
    6.4.126: न शसददवादिगुणानाम् ।
    """
    pass


@registry.register("6.4.127", text="अर्वणस्त्रसावनञः ।")
def rule_6_4_127(ctx=None):
    """
    6.4.127: अर्वणस्त्रसावनञः ।
    """
    pass


@registry.register("6.4.128", text="मघवा बहुलम् ।")
def rule_6_4_128(ctx=None):
    """
    6.4.128: मघवा बहुलम् ।
    """
    pass


@registry.register("6.4.129", text="भस्य ।")
def rule_6_4_129(ctx=None):
    """
    6.4.129: भस्य ।
    """
    pass


@registry.register("6.4.130", text="पादः पत् ।")
def rule_6_4_130(ctx=None):
    """
    6.4.130: पादः पत् ।
    """
    pass


@registry.register("6.4.131", text="वसोः सम्प्रसारणम् ।")
def rule_6_4_131(ctx=None):
    """
    6.4.131: वसोः सम्प्रसारणम् ।
    """
    pass


@registry.register("6.4.132", text="वाह ऊठ् ।")
def rule_6_4_132(ctx=None):
    """
    6.4.132: वाह ऊठ् ।
    """
    pass


@registry.register("6.4.133", text="श्वयुवमघोनामतद्धिते।")
def rule_6_4_133(ctx=None):
    """
    6.4.133: श्वयुवमघोनामतद्धिते।
    """
    pass


@registry.register("6.4.134", text="अल्लोपोऽनः ।")
def rule_6_4_134(ctx=None):
    """
    6.4.134: अल्लोपोऽनः ।
    """
    pass


@registry.register("6.4.135", text="षपूर्वहन्धृतराज्ञामणि ।")
def rule_6_4_135(ctx=None):
    """
    6.4.135: षपूर्वहन्धृतराज्ञामणि ।
    """
    pass


@registry.register("6.4.136", text="विभाषा ङिश्योः ।")
def rule_6_4_136(ctx=None):
    """
    6.4.136: विभाषा ङिश्योः ।
    """
    pass


@registry.register("6.4.137", text="न संयोगाद्वमान्तात् ।")
def rule_6_4_137(ctx=None):
    """
    6.4.137: न संयोगाद्वमान्तात् ।
    """
    pass


@registry.register("6.4.138", text="अचः ।")
def rule_6_4_138(ctx=None):
    """
    6.4.138: अचः ।
    """
    pass


@registry.register("6.4.139", text="उद ईत् ।")
def rule_6_4_139(ctx=None):
    """
    6.4.139: उद ईत् ।
    """
    pass


@registry.register("6.4.140", text="आतोधातोः ।")
def rule_6_4_140(ctx=None):
    """
    6.4.140: आतोधातोः ।
    """
    pass


@registry.register("6.4.141", text="मन्त्रेष्वाङ्यादेरात्मनः ।")
def rule_6_4_141(ctx=None):
    """
    6.4.141: मन्त्रेष्वाङ्यादेरात्मनः ।
    """
    pass


@registry.register("6.4.142", text="ति विंशतेर्डिति ।")
def rule_6_4_142(ctx=None):
    """
    6.4.142: ति विंशतेर्डिति ।
    """
    pass


@registry.register("6.4.143", text="टेः ।")
def rule_6_4_143(ctx=None):
    """
    6.4.143: टेः ।
    """
    pass


@registry.register("6.4.144", text="नस्तद्धिते।")
def rule_6_4_144(ctx=None):
    """
    6.4.144: नस्तद्धिते।
    """
    pass


@registry.register("6.4.145", text="अह्नष्टखोरेव ।")
def rule_6_4_145(ctx=None):
    """
    6.4.145: अह्नष्टखोरेव ।
    """
    pass


@registry.register("6.4.146", text="ओर्गुणः ।")
def rule_6_4_146(ctx=None):
    """
    6.4.146: ओर्गुणः ।
    """
    pass


@registry.register("6.4.147", text="ढेलोपोऽकद्र्वाः ।")
def rule_6_4_147(ctx=None):
    """
    6.4.147: ढेलोपोऽकद्र्वाः ।
    """
    pass


@registry.register("6.4.148", text="यस्येति च ।")
def rule_6_4_148(ctx=None):
    """
    6.4.148: यस्येति च ।
    """
    pass


@registry.register("6.4.149", text="सूर्यतिष्यागस्त्यमत्स्यानां य उपधायाः ।")
def rule_6_4_149(ctx=None):
    """
    6.4.149: सूर्यतिष्यागस्त्यमत्स्यानां य उपधायाः ।
    """
    pass


@registry.register("6.4.150", text="हलस्तद्धितस्य ।")
def rule_6_4_150(ctx=None):
    """
    6.4.150: हलस्तद्धितस्य ।
    """
    pass


@registry.register("6.4.151", text="आपत्यस्य च तद्धितेऽनाति ।")
def rule_6_4_151(ctx=None):
    """
    6.4.151: आपत्यस्य च तद्धितेऽनाति ।
    """
    pass


@registry.register("6.4.152", text="क्यच्व्योश्च ।")
def rule_6_4_152(ctx=None):
    """
    6.4.152: क्यच्व्योश्च ।
    """
    pass


@registry.register("6.4.153", text="बिल्वकादिभ्यश्छस्य लुक् ।")
def rule_6_4_153(ctx=None):
    """
    6.4.153: बिल्वकादिभ्यश्छस्य लुक् ।
    """
    pass


@registry.register("6.4.154", text="तुरिष्ठेमेयस्सु।")
def rule_6_4_154(ctx=None):
    """
    6.4.154: तुरिष्ठेमेयस्सु।
    """
    pass


@registry.register("6.4.155", text="टेः ।")
def rule_6_4_155(ctx=None):
    """
    6.4.155: टेः ।
    """
    pass


@registry.register("6.4.156", text="स्थूलदूरयुवह्रस्वक्षिप्रक्षुद्राणां यणादिपरं पूर्वस्य च गुणः ।")
def rule_6_4_156(ctx=None):
    """
    6.4.156: स्थूलदूरयुवह्रस्वक्षिप्रक्षुद्राणां यणादिपरं पूर्वस्य च गुणः ।
    """
    pass


@registry.register("6.4.157", text="प्रियस्थिरस्फिरोरुबहुलगुरुवृद्धतृप्रदीर्घ वृन्दारकाणां प्रस्थस्फवर्बंहिगर्वर्षित्रब्द्राघिवृन्दाः ।")
def rule_6_4_157(ctx=None):
    """
    6.4.157: प्रियस्थिरस्फिरोरुबहुलगुरुवृद्धतृप्रदीर्घ वृन्दारकाणां प्रस्थस्फवर्बंहिगर्वर्षित्रब्द्राघिवृन्दाः ।
    """
    pass


@registry.register("6.4.158", text="बहोर्लोपोभूच बहोः ।")
def rule_6_4_158(ctx=None):
    """
    6.4.158: बहोर्लोपोभूच बहोः ।
    """
    pass


@registry.register("6.4.159", text="इष्ठस्य यिट् च ।")
def rule_6_4_159(ctx=None):
    """
    6.4.159: इष्ठस्य यिट् च ।
    """
    pass


@registry.register("6.4.160", text="ज्यादादीयसः ।")
def rule_6_4_160(ctx=None):
    """
    6.4.160: ज्यादादीयसः ।
    """
    pass


@registry.register("6.4.161", text="र ऋतोहलादेर्लघोः ।")
def rule_6_4_161(ctx=None):
    """
    6.4.161: र ऋतोहलादेर्लघोः ।
    """
    pass


@registry.register("6.4.162", text="विभाषर्जोश्छन्दसि ।")
def rule_6_4_162(ctx=None):
    """
    6.4.162: विभाषर्जोश्छन्दसि ।
    """
    pass


@registry.register("6.4.163", text="प्रकृत्यैकाच् ।")
def rule_6_4_163(ctx=None):
    """
    6.4.163: प्रकृत्यैकाच् ।
    """
    pass


@registry.register("6.4.164", text="इनण्यनपत्ये।")
def rule_6_4_164(ctx=None):
    """
    6.4.164: इनण्यनपत्ये।
    """
    pass


@registry.register("6.4.165", text="गाथिविदथिकेशिगणिपणिनश्च ।")
def rule_6_4_165(ctx=None):
    """
    6.4.165: गाथिविदथिकेशिगणिपणिनश्च ।
    """
    pass


@registry.register("6.4.166", text="संयोगादिश्च ।")
def rule_6_4_166(ctx=None):
    """
    6.4.166: संयोगादिश्च ।
    """
    pass


@registry.register("6.4.167", text="अन् ।")
def rule_6_4_167(ctx=None):
    """
    6.4.167: अन् ।
    """
    pass


@registry.register("6.4.168", text="येचाभावकर्मणोः ।")
def rule_6_4_168(ctx=None):
    """
    6.4.168: येचाभावकर्मणोः ।
    """
    pass


@registry.register("6.4.169", text="आत्माध्वानौखे।")
def rule_6_4_169(ctx=None):
    """
    6.4.169: आत्माध्वानौखे।
    """
    pass


@registry.register("6.4.170", text="न मपूर्वोऽपत्येऽवर्मणः ।")
def rule_6_4_170(ctx=None):
    """
    6.4.170: न मपूर्वोऽपत्येऽवर्मणः ।
    """
    pass


@registry.register("6.4.171", text="ब्राह्मोअजातौ।")
def rule_6_4_171(ctx=None):
    """
    6.4.171: ब्राह्मोअजातौ।
    """
    pass


@registry.register("6.4.172", text="कार्मस्ताच्छील्ये।")
def rule_6_4_172(ctx=None):
    """
    6.4.172: कार्मस्ताच्छील्ये।
    """
    pass


@registry.register("6.4.173", text="औक्षमनपत्ये।")
def rule_6_4_173(ctx=None):
    """
    6.4.173: औक्षमनपत्ये।
    """
    pass


@registry.register("6.4.174", text="दाण्डिनायनहास्तिनायनाथर्वणिकजैह्माशिनेय वाशिनायनिभ्रौणहत्यधैवत्यसारवैक्ष्वाकमैत्रेयहिरण्मयानि ।")
def rule_6_4_174(ctx=None):
    """
    6.4.174: दाण्डिनायनहास्तिनायनाथर्वणिकजैह्माशिनेय वाशिनायनिभ्रौणहत्यधैवत्यसारवैक्ष्वाकमैत्रेयहिरण्मयानि ।
    """
    pass


@registry.register("6.4.175", text="ऋत्व्यवास्त्व्यवास्त्वमाध्वीहिरण्ययानि च्छन्दसि ।")
def rule_6_4_175(ctx=None):
    """
    6.4.175: ऋत्व्यवास्त्व्यवास्त्वमाध्वीहिरण्ययानि च्छन्दसि ।
    """
    pass
